@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 13/08/2024
+#Date last Update : 05/01/2025
 
 import vmpsys    as sys
 import vmputils  as utils
@@ -129,7 +129,8 @@ help_=[
        ("To Install module usage:","-m {name}"),
        ("To Get modules list:","-ml"),
        ("To Get module description:","-md {name}"),
-       ("Build symbolic link external lib within the vampire environment(see directory vmp-?/{0}):".format(config.glib_),"-l {libname(not .so extension)} {externalpath}"),
+       ("Build the symbolic link of an external software in the Bin directory of Vampiria","-se softwarename {externalpath}"),
+       ("Build symbolic link external lib within the vampiria environment(see directory vmp-?/{0}):".format(config.glib_),"-l {libname(not .so extension)} {externalpath}"),
        ("To install framework main doc(use doxygen)","-dm"),
        ("To Install framework c++ doc(use doxygen)","-dc"),
        ("To Install framework python doc(use doxygen)","-dp"),
@@ -219,5 +220,9 @@ if __name__ == "__main__":
       if sys.search_cmd("ln --help".split()):
         build.symlink_lib_build(args[1],args[2])
         sys.exit_ok()
+    elif args[0] == '-se':
+      if sys.search_cmd("ln --help".split()):
+        build.symlink_bin_build(args[1],args[2])
+        sys.exit_ok()
   utils.help(config.installer_,help_)
 
