@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 22/11/2024
+#Date last Update : 20/03/2025
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -123,7 +123,7 @@ def clear():
 
 vmplib=clib()
 vmplib.name='vmp'
-vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','ctype.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','sys/sysmacros.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
+vmplib.hdr=['assert.h','dirent.h','errno.h','fcntl.h','ctype.h','pwd.h','pthread.h','pty.h','signal.h','sys/time.h','sys/stat.h','sys/types.h','sys/wait.h','sys/ioctl.h','sys/sysmacros.h','net/if.h','string.h','strings.h','stdarg.h','stdio.h','stdlib.h','time.h','unistd.h']
 vmplib.files=[('./',['args','basetypes','buf','env','error','io','math','signal','thread','time','unicode','utils']),('lib/',['dev','fd','fs','lib','proc','types'])]
 vmplib.loptions=['-pthread','-lutil','-lc']
 vmplib.config=True
@@ -180,7 +180,7 @@ clibs_[moduleslib.name]=moduleslib
 
 jsonlib=clib()
 jsonlib.name='json'
-jsonlib.files=[('./',['json','japi','jdata','jtable','jlist'])]
+jsonlib.files=[('./',['json','jdata','jtable','jlist']),('japi/',['japi','misc','oper','peer','user'])]
 jsonlib.dependencies=['vmp','event','net','packet']
 jsonlib.libs=[('json-c','0.16')]
 jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
@@ -207,7 +207,7 @@ cryptolib=clib()
 cryptolib.name='crypto'
 cryptolib.dependencies=['vmp','net','event','json','packet','db']
 cryptolib.cmd=['openssl version','chmod --version','cp --version']
-cryptolib.files=[('./',['crypto','eventssl','eventp2p','eventwss','lib','hash','pkey','ssl','x509']),('ctx/',['ctx','base','https','peer']),('cb/',['sslcb','framingcb','p2pcb','wsscb'])]
+cryptolib.files=[('./',['crypto','eventssl','eventp2p','eventwss','lib','hash','pkey','ssl','sslbio','x509']),('ctx/',['ctx','base','https','peer']),('cb/',['sslcb','framingcb','p2pcb','wsscb'])]
 cryptolib.libs=[('openssl','3.0.9')]
 cryptolib.loptions=['`pkg-config --libs  openssl`']
 clibs_[cryptolib.name]=cryptolib
