@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 27/11/2024
+#Date last Update : 20/03/2025
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -170,7 +170,7 @@ vmp_crypto=pylib()
 vmp_crypto.name='vmp_crypto'
 vmp_crypto.dependencies=['vmp','vmp_net','vmp_event']
 vmp_crypto.cbuild()
-vmp_crypto.setup.files=[('./',['crypto_','hash_','pkey_','ctx_','ssl_','x509_'])]
+vmp_crypto.setup.files=[('./',['crypto_','hash_','pkey_','ctx_','ssl_','sslbio_','x509_'])]
 vmp_crypto.setup.dependencies=['pylib','crypto']
 pylibs_[vmp_crypto.name]=vmp_crypto
 
