@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 25/11/2019
+#Date last Update : 26/06/2024
 
 try:
   import sys
@@ -92,6 +92,13 @@ def write_file(path,strvalue):
   f.write(strvalue)
   f.close()
 
+##Copy the src file or directory recursively to dst<BR>
+#
+#@param src source file<BR>
+#@param dst destination file
+def cp_all(src,dst):
+  system("cp -r {0} {1} > /dev/null 2>&1".format(src,dst))
+
 ##Remove file<BR>
 #
 #@param filepath file path to remove
@@ -100,9 +107,13 @@ def rm_file(filepath):
 
 ##Remove Removes everything inside a directory<BR>
 #
-#@param dirpath directory path
-def rm_dir_all(dirpath):
-  system("rm -rf {0}/* > /dev/null 2>&1".format(dirpath))
+#@param dirpath directory path<BR>
+#@param drem remove directory empty?
+def rm_dir_all(dirpath,drem=False):
+  if drem:
+    system("rm -rf {0}/ > /dev/null 2>&1".format(dirpath))
+  else:
+    system("rm -rf {0}/* > /dev/null 2>&1".format(dirpath))
 
 ##Removes all object files(generated compiler c)<BR>
 #
@@ -121,6 +132,15 @@ def rm_cobj(rootpath,files):
 def getcwd():
   return "{0}/".format(os.getcwd())
 
+##Create directory empty
+#
+#@param directory path
+def mkdir(path):
+  try:
+    os.mkdir(path)
+  except Exception as e:
+    raise ValueError(e)
+  
 ##Change directory to work<BR>
 #
 #@param path new path directory
@@ -368,5 +388,22 @@ def config_remove(path):
   if isfile(path):
     system("rm {0}".format(path))
 
-
+##Create html index file for javascript project
+#
+#@param filepath file path to writes
+#@param title title page
+#@param rtag root tag
+#@param css css file list
+#@param js javascript file list
+def jsindex_create(filepath,title,rtag,css,js):
+  strcss=""
+  for c in css:
+    strcss="{0}\r\n    <link rel='StyleSheet' type='text/css' href='{1}'/>".format(strcss,c)
+  strjs=""
+  for j in js:
+    strjs="{0}\r\n    <script type='text/javascript' src='{1}' defer></script>".format(strjs,j)
+  rscript="\r\n    <script>\r\n      window.onload=function(){0}root=document.getElementById('root');root.init(){1};\r\n      window.onerror=function(message, url, line, col, errorObj){0}alert(`${0}message{1}\n${0}url{1}, ${0}line{1}:${0}col{1}`);{1};\r\n    </script>".format('{','}',rtag)
+  ret="<!doctype html>\r\n<html>\r\n  <head>\r\n    <title>{0}</title>{1}\r\n  </head>\r\n  <body>\r\n    <root-tag id='root'></root-tag>{2}{3}\r\n  </body>\r\n</html>".format(title,strcss,rscript,strjs)
+  write_file(filepath,ret)
+  
 
