@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 04/09/2024
+#Date last Update : 31/12/2024
 
 ##@package vmp
 #
@@ -75,6 +75,15 @@ from vmp_ import pause_wrap   as pause_wrap
 from vmp_ import getpid_wrap  as getpid_wrap
 from vmp_ import getuid_wrap  as getuid_wrap
 from vmp_ import geteuid_wrap as geteuid_wrap
+from vmp_ import getuid_user  as getuid_user
+from vmp_ import getgid_user  as getgid_user
+from vmp_ import getgid_wrap  as getgid_wrap
+from vmp_ import getegid_wrap as getegid_wrap
+from vmp_ import setuid_wrap  as setuid_wrap
+from vmp_ import setgid_wrap  as setgid_wrap
+from vmp_ import setuid_user  as setuid_user
+from vmp_ import setgid_user  as setgid_user
+
 from vmp_ import kill_wrap    as kill_wrap
 
 from vmp_ import dup2_wrap    as dup2_wrap
@@ -147,6 +156,21 @@ def input_f(name,f):
   except Exception as e:
     except_s(str(e))
 
+##Adds data inputs to custom inputs to pass to a process
+#
+#@param cinput custom input
+#@param name input name
+#@param par parlist
+#@param var varlist
+def custom_input_add(cinput,name,par,var):
+  try:
+    if name in cinput:
+      cinput[name].append(par,var)
+    else:
+      cinput[name]=[(par,var)]
+  except Exception as e:
+    except_s(str(e))
+
 def external_module_error(name):
   except_s("Python Module \'{0}\' not found,install it.".format(name))
 
