@@ -105,7 +105,7 @@ void vmp_init_unicode(pylib::Module module)
     unicode.def_("b64_decode",vmp::unicode::b64_decode);
     unicode.def_("utf8_check",vmp::unicode::utf8_check);
 
-    pylib::Class<vmp::unicode::Strtok> strtok=module.class_with_constructor<vmp::unicode::Strtok>("Strtok",PyStrtok_stub_Constructor());
+    pylib::Class<vmp::unicode::Strtok> strtok=unicode.class_with_constructor<vmp::unicode::Strtok>("Strtok",PyStrtok_stub_Constructor());
     strtok.def_("reset",&vmp::unicode::Strtok::reset);
     strtok.def_("set",&vmp::unicode::Strtok::set);
     strtok.def_("next",&vmp::unicode::Strtok::next);
