@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/02/2020
+   Date last update: 08/01/2025
  */
 
 #include "vmp_.h"
@@ -34,8 +34,13 @@ void vmp_init_utils(pylib::Module module)
 
      pylib::Class<vmp::utils::Logger> logger=utils.class_<vmp::utils::Logger>("Logger");
      logger.def_("reset",&vmp::utils::Logger::reset);
+     logger.def_("logname",&vmp::utils::Logger::logname);
+     logger.def_("loglevel",&vmp::utils::Logger::loglevel);
      logger.def_("set",&vmp::utils::Logger::set);
      logger.def_("write",&vmp::utils::Logger::write_s);
      logger.def_("rotate",&vmp::utils::Logger::rotate);
+     
+     utils.def_("syslog_build",vmp::utils::syslog_build);
+     utils.def_("syslog",vmp::utils::syslog_s);
 }
 
