@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 10/10/2024
+#Date last Update : 03/01/2025
 
 import vmp
 import vmp_net
@@ -50,7 +50,11 @@ from vmp_jrp_  import max_permits as max_permits
 
 from vmp_jrp_  import msg_status as msg_status
 
-from vmp_jrp_  import JrpCommon as JrpCommon
+from vmp_jrp_  import JrpCommon        as JrpCommon
+from vmp_jrp_  import sessiontype      as sessiontype
+from vmp_jrp_  import sessionid        as sessionid
+from vmp_jrp_  import sessionpermits   as sessionpermits
+
 from vmp_jrp_  import JrpReq    as JrpReq
 from vmp_jrp_  import misc      as misc
 from vmp_jrp_  import jrpui     as jrpui
