@@ -24,8 +24,10 @@ import vmp_net         as net
 import vmp_plugin.base as base
 import vmp_json        as json
 import vmp_crypto      as crypto
-from vmp_jrp_  import JrpUI     as JrpUI
-from vmp_jrp_  import JrpCommon as JrpCommon
+from vmp_jrp_  import JrpUI       as JrpUI
+from vmp_jrp_  import JrpCommon   as JrpCommon
+from vmp_jrp_  import min_permits as min_permits
+from vmp_jrp_  import max_permits as max_permits
 
 ptype_="client.jrp"
 
@@ -54,6 +56,9 @@ def close(cell):
   elif plugin.exitlevel == "crypto::EventSslFramingPeer":
     vmp.output("\nServer Close (exitlevel={0},errocde={1},errmsg={2})".format(plugin.exitlevel,plugin.exitcode,plugin.exitmsg))
     plugin.prompt();
+  elif plugin.exitlevel == "crypto::EventSsl":
+    vmp.output("\nServer Close from remote peer(exitlevel={0},errocde={1},errmsg={2})".format(plugin.exitlevel,plugin.exitcode,plugin.exitmsg))
+    plugin.prompt();
 
 def response_d(jreq,data,payload):
   cell=jreq.cell()
@@ -117,7 +122,7 @@ def connect(plugin,args):
     vmp.error("Client already connected to a peer")
     vmp.time.vsleep(0.1)
   
-def connectstatus(plugin,args):
+def connectinfo(plugin,args):
   if plugin.peerstatus == "close":
     if plugin.exitcode == None:
       vmp.output("Disconnect")
@@ -296,7 +301,31 @@ def peerdel(plugin,args):
   except Exception as e:
     vmp.error(str(e))
     vmp.time.vsleep(0.1)
-   
+
+def connectlist(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('connectinfo')
+    j=json.Json()
+    json.japi_connectlist(j.root())
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'connectinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)  
+
+def connectclose(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('connectinfo')
+    j=json.Json()
+    json.japi_connectclose(j.root(),args[0],args[1])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'connectinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
 #Internal usage
 class Requests:
   def __init__(self,jreq):
@@ -403,7 +432,7 @@ class Plugin(base.Plugin):
     self.add_command("helper","Helper command",0,[('command name','generic')],helper)
     self.add_command("local","Information about the identity of the local peer",0,[],local)
     self.add_command("connect","Connect to jrp peer",2,[('host address peer','generic'),('host service','integer',1,65535)],connect)
-    self.add_command("connectstatus","Print connection client status",0,[],connectstatus)
+    self.add_command("connectinfo","Print connection client info",0,[],connectinfo)
     self.add_command("disconnect","Disconnect peer",0,[],disconnect)
     self.add_command("requests","List of requests sent",0,[],requests)
     self.add_command("kill","Send a kill message to a request ",1,[("request number",'integer',0,None)],kill)
@@ -419,6 +448,8 @@ class Plugin(base.Plugin):
     self.add_command("peeradd","Add a peer",3,[('fingerprint peer','generic'),('subject peer','generic'),('user permits','integer',0,vmp.INTMAX)],peeradd)
     self.add_command("peermod","Change ownership of a peer",2,[('fingerprint peer','generic'),('user permits','integer',0,vmp.INTMAX)],peermod)
     self.add_command("peerdel","Delete a peer",1,[('fingerprint','generic')],peerdel)
+    self.add_command("connectlist","List of connections",0,[],connectlist)
+    self.add_command("connectclose","Close connection",2,[('connection id','generic'),('connection type','generic')],connectclose)
     self.ctx=crypto.Ctx_Peer(vmp.fs.union_path(self.rootpath,"x509"),1,self.subject)
     
     if self.debug:
@@ -602,7 +633,7 @@ class Plugin(base.Plugin):
       self.delvar('status',key)
     elif jd.jtype() == json.japi("peerinfo"):
       fng=jd.get_text("fingerprint")
-      d={'fingerprint':fng,'subject':jd.get_text('subject'),'permits':jd.get_integer_range('permits',0,vmp.INTMAX)}
+      d={'fingerprint':fng,'subject':jd.get_text('subject'),'permits':jd.get_integer_range('permits',min_permits,max_permits)}
       value="{0}".format(d)
       self.setvar('peerinfo',fng,value,"peer info")
     elif jd.jtype() == json.japi("userinfo"):
@@ -611,9 +642,14 @@ class Plugin(base.Plugin):
         o="True"
       else:
         o="False"
-      d={'user':user,'permits':jd.get_integer_range('permits',0,vmp.INTMAX),'only_localhost':o}
+      d={'user':user,'permits':jd.get_integer_range('permits',min_permits,max_permits),'only_localhost':o}
       value="{0}".format(d)
       self.setvar('userinfo',user,value,"user '{0}' info".format(user))
+    elif jd.jtype() == json.japi("connectinfo"):
+      cid=jd.get_text("id")
+      d={'id':cid,'type':jd.get_text("type"),'permits':jd.get_integer_range('permits',min_permits,max_permits)}
+      value="{0}".format(d)
+      self.setvar('connectinfo',cid,value,"connection")
     else:
       self.response(jreq,jdata)
     
@@ -622,7 +658,7 @@ class Plugin(base.Plugin):
     jd=json.JData()
     jd.set(jreq.jdata_root())
     t=jd.jtype()
-    if (t == json.japi("userlist")) or (t == json.japi("useradd")) or (t == json.japi("usermod")) or (t == json.japi("userpasswd")) or (t == json.japi("userdel")) or (t == json.japi("peerlist")) or (t == json.japi("peeradd")) or (t == json.japi("peermod")) or (t == json.japi("peerdel")):
+    if (t == json.japi("userlist")) or (t == json.japi("useradd")) or (t == json.japi("usermod")) or (t == json.japi("userpasswd")) or (t == json.japi("userdel")) or (t == json.japi("peerlist")) or (t == json.japi("peeradd")) or (t == json.japi("peermod")) or (t == json.japi("peerdel")) or (json.japi("connectlist")) or (json.japi("connectclose")):
       self.unbusy()
     self.close(jreq)
     
