@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 02/10/2024
+ * Date last update: 30/11/2024
 */
  
 #ifndef VAMPIRIA_PY_JRP_EVENTJRP_H
@@ -37,10 +37,6 @@ class PyJrpCommon:public jrp::JrpCommon
         pylib::PyCall pykillcb_;
         pylib::PyCall pyclosecb_;
         
-        pylib::PyCall pyrequestforwardcb_;
-        pylib::PyCall pypushforwardcb_;
-        pylib::PyCall pyresponseforwardcb_;
-    
         pylib::PyCall pybroadcastcb_;
 };
 
