@@ -16,26 +16,11 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 26/11/2024
+ * Date last update: 07/01/2025
  */
  
 #include "jrp_.h"
 
-class PyJrpUI:public jrp::JrpUI
-{
-   public:
-        PyJrpUI(event::Manager *manager,crypto::Ctx_Peer *ctx,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger=0,vmp::time::Time ctimeout=0);
-        ~PyJrpUI();
-
-        pylib::PyCall pytcpconnect_;
-        pylib::PyCall pysessionclient_;
-        pylib::PyCall pytcpaccept_;
-        pylib::PyCall pysessionserver_;
-        pylib::PyCall pycloseclient_;
-        pylib::PyCall pycloselisten_;
-        pylib::PyCall pycloseserver_;
-};
-
 PyJrpUI::PyJrpUI(event::Manager *manager,crypto::Ctx_Peer *ctx,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger,vmp::time::Time ctimeout):jrp::JrpUI(manager,ctx,jrpcommon,logger,ctimeout)
 {
 }
@@ -243,6 +228,22 @@ struct stub_JrpUI_new_client:public pylib::Member_def<PyJrpUI>
     }
 };
 
+struct stub_JrpUI_connect_search:public pylib::Member_def<PyJrpUI>
+{
+    pylib::Objref *def(PyJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            vmp::str fingerprint=args.get<vmp::str>(0);
+            event::Cell *cell=instance->connect_search(fingerprint);
+            if(cell == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(cell,false);
+        }
+        return 0;
+    }
+};
+
 struct stub_JrpUI_search_peer:public pylib::Member_def<PyJrpUI>
 {
     pylib::Objref *def(PyJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -336,18 +337,6 @@ struct stub_JrpUI_broadcast:public pylib::Member_def<PyJrpUI>
     }
 };
 
-class PyWssJrpUI:public jrp::WssJrpUI
-{
-   public:
-        PyWssJrpUI(event::Manager *manager,crypto::Ctx_Peer_Web *ctx,vmp::str webroot,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger=0,vmp::time::Time ctimeout=0);
-        ~PyWssJrpUI();
-
-        pylib::PyCall pytcpaccept_;
-        pylib::PyCall pysession_;
-        pylib::PyCall pycloselisten_;
-        pylib::PyCall pycloseserver_;
-};
-
 PyWssJrpUI::PyWssJrpUI(event::Manager *manager,crypto::Ctx_Peer_Web *ctx,vmp::str webroot,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger,vmp::time::Time ctimeout):jrp::WssJrpUI(manager,ctx,webroot,jrpcommon,logger,ctimeout)
 {
 }
@@ -484,7 +473,6 @@ struct stub_WssJrpUI_new_listen:public pylib::Member_def<PyWssJrpUI>
 {
     pylib::Objref *def(PyWssJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
     {
-        
         if(args.size() == 4)
         {
             net::Address *local=args.get<net::Address *>(0);
@@ -508,6 +496,22 @@ struct stub_WssJrpUI_new_listen:public pylib::Member_def<PyWssJrpUI>
     }
 };
 
+struct stub_WssJrpUI_connect_search:public pylib::Member_def<PyWssJrpUI>
+{
+    pylib::Objref *def(PyWssJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            vmp::str user=args.get<vmp::str>(0);
+            event::Cell *cell=instance->connect_search(user);
+            if(cell == 0)
+                return pylib::retnone();
+            return pylib::Converter<event::Cell *>(cell,false);
+        }
+        return 0;
+    }
+};
+
 struct stub_WssJrpUI_broadcast:public pylib::Member_def<PyWssJrpUI>
 {
     pylib::Objref *def(PyWssJrpUI *instance,pylib::Args &args,pylib::KwArgs &kwargs)
@@ -580,6 +584,8 @@ void jrp_init(pylib::Module module)
     jrpui.def_("jrpcommon",&PyJrpUI::jrpcommon,false);
     jrpui.def_("ctx",&PyJrpUI::ctx,false);
     jrpui.def_("logger",&PyJrpUI::logger,false);
+    jrpui.def_with_stub("connect_search",stub_JrpUI_connect_search());
+    jrpui.def_("connect_list",&PyJrpUI::connect_list);
     jrpui.def_("permits",&PyJrpUI::permits);
     jrpui.def_("get_peer_x509",&PyJrpUI::get_peer_x509);
     jrpui.def_("peer_fingerprint",&PyJrpUI::peer_fingerprint);
@@ -622,8 +628,11 @@ void jrp_init(pylib::Module module)
     wssjrpui.def_("jrpcommon",&PyWssJrpUI::jrpcommon,false);
     wssjrpui.def_("ctx",&PyWssJrpUI::ctx,false);
     wssjrpui.def_("logger",&PyWssJrpUI::logger,false);
-    wssjrpui.def_("peer_user",&PyWssJrpUI::peer_user);
-    wssjrpui.def_("peer_permits",&PyWssJrpUI::peer_permits);
+    wssjrpui.def_with_stub("connect_search",stub_WssJrpUI_connect_search());
+    wssjrpui.def_("connect_list",&PyWssJrpUI::connect_list);
+    wssjrpui.def_("user",&PyWssJrpUI::user);
+    wssjrpui.def_("permits",&PyWssJrpUI::permits);
+    wssjrpui.def_("permits_u",&PyWssJrpUI::permits_u);
     wssjrpui.def_with_stub("broadcast",stub_WssJrpUI_broadcast());
 }
 
