@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 27/12/2024
+ * Date last update: 07/01/2025
  */
 
 #include "pylib.h"
@@ -49,6 +49,35 @@ void jrp_eventjrp(pylib::Module module);
 */
 void jrp_jrpreq(pylib::Module module);
 
+//!Wrapper python JrpUi
+class PyJrpUI:public jrp::JrpUI
+{
+   public:
+        PyJrpUI(event::Manager *manager,crypto::Ctx_Peer *ctx,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger=0,vmp::time::Time ctimeout=0);
+        ~PyJrpUI();
+
+        pylib::PyCall pytcpconnect_;
+        pylib::PyCall pysessionclient_;
+        pylib::PyCall pytcpaccept_;
+        pylib::PyCall pysessionserver_;
+        pylib::PyCall pycloseclient_;
+        pylib::PyCall pycloselisten_;
+        pylib::PyCall pycloseserver_;
+};
+
+//!Wrapper python WssJrpUi
+class PyWssJrpUI:public jrp::WssJrpUI
+{
+   public:
+        PyWssJrpUI(event::Manager *manager,crypto::Ctx_Peer_Web *ctx,vmp::str webroot,jrp::JrpCommon *jrpcommon,vmp::utils::Logger *logger=0,vmp::time::Time ctimeout=0);
+        ~PyWssJrpUI();
+
+        pylib::PyCall pytcpaccept_;
+        pylib::PyCall pysession_;
+        pylib::PyCall pycloselisten_;
+        pylib::PyCall pycloseserver_;
+};
+
 //!Python wrapper of the c++ namespace vampiria::jrp in vmp_jrp.(see c++ doc)
 /*!
     Const c++ in jrp.h":<BR>
@@ -71,14 +100,14 @@ void jrp_jrpreq(pylib::Module module);
     JrpUI member function list:<BR>
     set_p2p_client_event(),set_p2p_server_event(),set_key_update(),new_client(),
     new_listen(),localaddr(),peeraddr(),proxyinfo(),connection_type(),
-    connection_strtype(),jrpcommon(),ctx(),logger(),permits(),permits_f(),
-    get_peer_x509(),peer_fingerprint(),peer_subject(),peer_permits(),
-    peer_nodetype(),peer_subject_f(),peer_permits_f(),peer_nodetype_f(),
-    search_peer(),search_peer_p(),search_peer_o(),all_input(),all_input_f(),
-    search_input_push(),search_input_push_f(),search_input_response(),
-    search_input_response_f(),search_push(),search_push_f(),search_response(),
-    search_response_f(),broadcastdata_peer(),broadcastdata_peer_f(),request(),
-    request_f(),broadcast()
+    connection_strtype(),jrpcommon(),ctx(),logger(),connect_list(),
+    connect_search(),permits(),permits_f(),get_peer_x509(),peer_fingerprint(),
+    peer_subject(),peer_permits(),peer_nodetype(),peer_subject_f(),
+    peer_permits_f(),peer_nodetype_f(),search_peer(),search_peer_p(),
+    search_peer_o(),all_input(),all_input_f(),search_input_push(),
+    search_input_push_f(),search_input_response(),search_input_response_f(),
+    search_push(),search_push_f(),search_response(),search_response_f(),
+    broadcastdata_peer(),broadcastdata_peer_f(),request(),request_f(),broadcast()
 */
 /*!
     Wrapper Cell->ui() for jrp in wssjrpui(cell)<BR>
@@ -88,8 +117,8 @@ void jrp_jrpreq(pylib::Module module);
     WssJrpUI class in jrp.h:<BR>Constructor WssJrpUI(manager,ctx_peer_web,webroot,jrpcommon,logger=None,ctimeout=0)<BR>
     WssJrpUI member function list:<BR>
     set_http(),set_wss_event(),new_listen(),localaddr(),connection_type(),
-    connection_strtype(),jrpcommon(),ctx(),logger(),peer_user(),peer_permits(),
-    broadcast()
+    connection_strtype(),jrpcommon(),ctx(),logger(),connect_search(),
+    connect_list(),user(),permits(),permits_u(),broadcast()
 */
 void jrp_init(pylib::Module module);
 
@@ -121,6 +150,12 @@ void jrp_misc_status(pylib::Module module);
     Peer member function list:<BR>
     register_common(),management()
     
+*/
+/*!
+    ConnectStatus class in jrp/misc/utils.h:<BR>Constructor ConnectStatus(jrpui,wssjrpui)<BR>
+    Peer member function list:<BR>
+    register_common(),management()
+    
 */
 void jrp_misc_utils(pylib::Module module);
 
