@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 22/11/2024
+ * Date last update: 20/03/2025
  */
 
 #include "json_.h"
@@ -314,11 +314,30 @@ struct stub_japi_userpasswd:public pylib::Generic_def
             json::japi_userpasswd(obj,user,password,md5_password);
             return pylib::retnone();
         }
-        
         return 0;
     }
 };
 
+struct stub_japi_connectinfo:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 7)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str id=args.get<vmp::str>(1);
+            vmp::str type=args.get<vmp::str>(2);
+            vmp::str aux=args.get<vmp::str>(3);
+            vmp_uint permits=args.get<vmp_uint>(4);
+            vmp::str address=args.get<vmp::str>(5);
+            vmp_uint port=args.get<vmp_uint>(6);
+            json::japi_connectinfo(obj,id,type,aux,permits,address,port);
+            return pylib::retnone();
+        }
+       return 0;
+    }
+};
+
 void json_japi(pylib::Module module)
 {
     module.def_("japi",json::japi);
@@ -350,5 +369,8 @@ void json_japi(pylib::Module module)
     module.def_("japi_peeradd",json::japi_peeradd);
     module.def_("japi_peermod",json::japi_peermod);
     module.def_("japi_peerdel",json::japi_peerdel);
+    module.def_("japi_connectlist",json::japi_connectlist);
+    module.def_with_stub("japi_connectinfo",stub_japi_connectinfo());
+    module.def_("japi_connectclose",json::japi_connectclose);
 }
 
