@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 22/11/2024
+ * Date last update: 07/01/2025
  */
 
 #include "pylib.h"
@@ -89,11 +89,15 @@ void json_jtable(pylib::Module module);
 
 //!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
 /*!
-    Function c++ in json/japi.h:<BR>japi(),japi_type_list(),japi_type_table(),japi_void(),japi_list(),japi_table(),
-                                    japi_oper(),japi_oper_kill(),japi_oper_data(),japi_oper_push(),japi_oper_close(),japi_status(),
-                                    japi_status_update(),japi_status_cancel(),japi_login(),japi_login_b64_e(),japi_login_b64_d(),
-                                    japi_passwd(),japi_userlist(),japi_userinfo(),japi_useradd(),japi_usermod(),japi_userpasswd(),
-                                    japi_userdel(),japi_peerlist(),japi_peerinfo(),japi_peeradd(),japi_peermod(),japi_peerdel()
+    Function c++ in json/japi.h:<BR>
+    japi(),japi_type_list(),japi_type_table(),japi_void(),japi_list(),japi_table(),
+    japi_oper(),japi_oper_kill(),japi_oper_data(),japi_oper_push(),
+    japi_oper_close(),japi_status(),japi_status_update(),japi_status_cancel(),
+    japi_login(),japi_login_b64_e(),japi_login_b64_d(),japi_passwd(),
+    japi_userlist(),japi_userinfo(),japi_useradd(),japi_usermod(),
+    japi_userpasswd(),japi_userdel(),japi_peerlist(),japi_peerinfo(),
+    japi_peeradd(),japi_peermod(),japi_peerdel(),japi_connectlist(),
+    japi_connectinfo(),japi_connectclose()
 */
 void json_japi(pylib::Module module);
 
