@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 22/02/2020
+   Date last update: 09/01/2024
  */
 
 #include "net_.h"
@@ -69,6 +69,13 @@ struct stub_address_set:public pylib::Member_def<net::Address>
             vmp::str service=args.get<vmp::str>(1);
             instance->set(host,service);
         }
+        else if(args.size() == 3)
+        {
+            vmp::str host=args.get<vmp::str>(0);
+            vmp::str service=args.get<vmp::str>(1);
+            vmp_bool onlyhost=args.get<vmp_bool>(2);
+            instance->set(host,service,onlyhost);
+        }
         else    
             return 0;
         return pylib::retnone();
@@ -109,5 +116,6 @@ void net_init_address(pylib::Module module)
     address.def_("service",&net::Address::service);
     address.def_("is_ipv4",&net::Address::is_ipv4);
     address.def_("is_ipv6",&net::Address::is_ipv6);
+    address.def_("is_onlyhost",&net::Address::is_onlyhost);
 }
 
