@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 09/04/2024
+#Date last Update : 06/03/2025
 
 import vmp
 
@@ -36,6 +36,7 @@ class PluginTopic:
     self.desc="no description"
     self.data=[]
     self.function=[]
+    self.var=[]
     self.options=[]
 
   ##Set plugin description<BR>
@@ -80,6 +81,12 @@ class PluginTopic:
         self.function[i][2]=args
         self.function[i][3]=ret
 
+  ##Adds a variable value to the plugin, it is not a classic option and must be used in sequence before the options
+  #
+  #@param optdesc description var
+  def add_var(self,optdesc):
+    self.var.append(optdesc)
+    
   ##Adds the description of optional data. Optional data can be different between plugins of the same type and have the form "data_name value"
   #
   #@param optname option name<BR>
@@ -109,8 +116,10 @@ class PluginTopic:
       if f[3] != None:
         ret += "    <return>\n      {0}\n    </return>\n".format(f[3])
       ret += "  </Function>\n"
+    for i in range(0,len(self.var)):
+      ret+="  <Var{0}>\n    {1}\n  </Var{0}>\n".format(i,self.var[i])
     for o in self.options:
-      ret += "\n  <Option format=\'{0} $VALUE\' default_value=\'{1}\' occurrences_used=\'{2}\'>\n    {3}\n  </Option>".format(o[0],o[1],o[2],o[3])
+      ret += "  <Option format=\'{0} $VALUE\' default_value=\'{1}\' occurrences_used=\'{2}\'>\n    {3}\n  </Option>\n".format(o[0],o[1],o[2],o[3])
     ret +="</Plugin>"
     return ret
 
