@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 17/10/2024
+   Date last update: 21/01/2025
  */
  
 #ifndef VAMPIRIA_CRYPTO_EVENTSSL_H
@@ -289,6 +289,7 @@ class EventSsl:public net::EventConnection
         crypto::SslCommon *common_;/*!<Shared object for all events*/
         crypto::Ssl ssl_;/*!<Ssl connection associated*/
         vmp::time::Time ctimeout_;/*!<Connection timeout*/
+        vmp::str shutdownlevel_;/*!<Internal usage*/
         
         packet::websocket::FramingHelper framing_;/*!<Framing protocol helper*/
         vmp_uint framingcode_;/*!<Frame close code,used in evt_wss_frame_close()*/
@@ -414,6 +415,13 @@ class EventSsl:public net::EventConnection
         void evt_ssl_free();
 };
 
+//!Shutdown ssl connection(Monitor mode)
+/*!
+    @param cell Cell with associated ssl event
+    @param closelevel close level value
+*/
+void ssl_shutdown(event::Cell *cell,vmp::str closelevel="");
+
 }}
 
 #endif
