@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/10/2024
+   Date last update: 07/01/2025
  */
 
 #include "vmp.h"
@@ -96,7 +96,7 @@ class Cell:public vmp::utils::Container<vmp::str>
 {
     private:
        friend event::Manager;
-       event::CELLSTATE state_;   /*!< Cell state*/
+       event::CELLSTATE state_;/*!< Cell state*/
        vmp_index id_;/*!<Cell identification*/
        
        vmp_index   nwait_;        /*!< Number of events executable in the state CLOSEWAIT*/
@@ -108,8 +108,7 @@ class Cell:public vmp::utils::Container<vmp::str>
        
        //! Reset cell
        void reset();
-
-     public:
+   public:
        //! A Constructor
        Cell();
 
@@ -130,7 +129,25 @@ class Cell:public vmp::utils::Container<vmp::str>
        
        vmp::str evtype_;  /*!<Used in UI for managing multiple event types(default generic)*/
        vmp_bool writing_; /*!<True writing associated select fd,otherwise false(default false)*/
-
+       
+       //!Return true if the cell is active(monitor mode)
+       /*!
+           @return true if the cell is active,otherwise false
+       */
+       vmp_bool is_active();
+       
+       //!Return true if the cell status is closewait(monitor mode)
+       /*!
+           @return true if the cell status is closewait,otherwise false
+       */
+       vmp_bool is_closewait();
+       
+       //!Return true if the cell status is close(monitor mode)
+       /*!
+           @return true if the cell status is close,otherwise false
+       */
+       vmp_bool is_close();
+       
        //!Return a string that identifies the event(monitor)
        /*!
            @return string identity
@@ -364,7 +381,7 @@ class Manager
         vmp_bool forced_unlock();
 
         //! Recovery lock after a forced_unlock() call
-        /*!vmp::str errinfo="",vmp::str errlevel="",vmp_int errcode=0
+        /*!
             @param status value returned from forced_unlock() function
         */
         void recovery_lock(vmp_bool status);        
