@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/11/2024
+   Date last update: 07/01/2025
 */
 
 #include "vmp.h"
@@ -207,6 +207,19 @@ class JrpUI:public event::UI
         */
         vmp::utils::Logger *logger();
 
+        //!Search for the connection associated with the fingeprint(monitor mode)
+        /*!
+            @param fingerprint fingerprint peer
+            @return event cell or 0 if the user not found
+        */
+        event::Cell *connect_search(vmp::str fingerprint);
+        
+        //!The list of connected fingerprints returns
+        /*!
+            @return fingerprint list
+        */
+        vmp::vector<vmp::str> connect_list();
+        
         //! Permission assigned by remote peer to local peer(monitor mode)
         /*!
             @param cell cell associated
@@ -538,19 +551,39 @@ class WssJrpUI:public event::UI
         */
         vmp::utils::Logger *logger();
         
+        //!Search for the connection associated with the user(monitor mode)
+        /*!
+            @param user user search
+            @return event cell or 0 if the user not found
+        */
+        event::Cell *connect_search(vmp::str user);
+        
+        //!The list of connected user returns
+        /*!
+            @return user list
+        */
+        vmp::vector<vmp::str> connect_list();
+        
         //! Returns the user associated with the input cell(monitor mode)
         /*!
             @param cell event cell
             @return user associated
         */
-        vmp::str peer_user(event::Cell *cell);
+        vmp::str user(event::Cell *cell);
 
         //! Returns the permits of the user associated with the input cell(monitor mode)
         /*!
             @param cell input cell
             @return permits user
         */
-        vmp_uint peer_permits(event::Cell *cell);
+        vmp_uint permits(event::Cell *cell);
+        
+        //! Returns the permits of the user (monitor mode)
+        /*!
+            @param user input user
+            @return permits user or except in case the failure
+        */
+        vmp_uint permits_u(vmp::str user);
         
         //! Send a jrp broadcast message(monitor mode)
         /*!
