@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/11/2024
+   Date last update: 14/01/2025
 */
 
 #include "jrp.h"
@@ -217,9 +217,9 @@ void jrp_recv_peer(event::Cell *cell,vmp::Buf *buf)
                 if(res)
                 {
                     req->recv_close(msg.status_,msg.msg_);
-                    req->release_internal();
                     manager->unlock();
                     jrp->common_->closecb_(req);
+                    req->release();
                 }
                 else
                     manager->unlock();
