@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/11/2024
+   Date last update: 07/01/2025
 */
 
 #include "jrp.h"
@@ -305,6 +305,24 @@ vmp::utils::Logger *JrpUI::logger()
     return logger_;
 }
 
+event::Cell *JrpUI::connect_search(vmp::str fingerprint)
+{
+    event::Cell *ret=0;
+    manager_->lock();
+    p2pcommon_->p2ptable_.search(fingerprint,&ret);
+    manager_->unlock();
+    return ret;
+}
+
+vmp::vector<vmp::str> JrpUI::connect_list()
+{
+    vmp::vector<vmp::str> ret;
+    manager_->lock();
+    ret=p2pcommon_->p2ptable_.all_keys();
+    manager_->unlock();
+    return ret;
+}
+
 vmp_uint JrpUI::permits(event::Cell *cell)
 {
     event::Manager *manager=cell->get_manager();
@@ -725,6 +743,7 @@ WssJrpUI::WssJrpUI(event::Manager *manager,crypto::Ctx_Peer_Web *ctx,vmp::str we
     wsscommon_=new crypto::WssCommon(manager);
     wsscommon_->set_wss_init(ctx,webroot,ctimeout);
     wsscommon_->set_wss_event(jrp::wssjrpui_tcpacceptcb,wssjrpui_sessioncb,jrp::wssjrpui_lclosecb,jrp::wssjrpui_sclosecb);
+    set_wss_event(0,0,0,0);
 }
 
 WssJrpUI::~WssJrpUI()
@@ -887,7 +906,25 @@ vmp::utils::Logger *WssJrpUI::logger()
     return logger_;
 }
 
-vmp::str WssJrpUI::peer_user(event::Cell *cell)
+event::Cell *WssJrpUI::connect_search(vmp::str user)
+{
+    event::Cell *ret=0;
+    manager_->lock();
+    wsscommon_->usertable_.search(user,&ret);
+    manager_->unlock();
+    return ret;
+}
+
+vmp::vector<vmp::str> WssJrpUI::connect_list()
+{
+    vmp::vector<vmp::str> ret;
+    manager_->lock();
+    ret=wsscommon_->usertable_.all_keys();
+    manager_->unlock();
+    return ret;
+}
+
+vmp::str WssJrpUI::user(event::Cell *cell)
 {
     event::Manager *manager=cell->get_manager();
     manager->lock();
@@ -897,7 +934,7 @@ vmp::str WssJrpUI::peer_user(event::Cell *cell)
     return ret;
 }
 
-vmp_uint WssJrpUI::peer_permits(event::Cell *cell)
+vmp_uint WssJrpUI::permits(event::Cell *cell)
 {
     event::Manager *manager=cell->get_manager();
     manager->lock();
@@ -907,6 +944,18 @@ vmp_uint WssJrpUI::peer_permits(event::Cell *cell)
     return ret;
 }
 
+vmp_uint WssJrpUI::permits_u(vmp::str user)
+{
+    event::Cell *cell;
+    manager_->lock();
+    if(!wsscommon_->usertable_.search(user,&cell))
+        vmp::except("jrp::WssJrpUI::permits_u(user='%s') not found",user.c_str());
+    crypto::EventWss *wss=cell->event<crypto::EventWss>();
+    vmp_uint ret=wss->sub_->sessionpermits_;
+    manager_->unlock();
+    return ret;
+}
+
 void WssJrpUI::broadcast(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *payload)
 {
     event::Manager *manager=cell->get_manager();
