@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/11/2024
+   Date last update: 14/01/2025
 */
 
 #include "jrp.h"
@@ -50,11 +50,6 @@ JrpReq::~JrpReq()
     reset();
 }
 
-jrp::JrpCommon *JrpReq::common()
-{
-    return common_;
-}
-
 event::Manager *JrpReq::get_manager()
 {
     if(cell_ == 0)
@@ -113,38 +108,57 @@ void JrpReq::reset()
     msg_="";
 }
 
+void JrpReq::check_counter(vmp::str fname)
+{
+    if(count_ == 0)
+      vmp::except("jrp::Jrpreq::%() request is free",fname.c_str());
+}
+
+jrp::JrpCommon *JrpReq::common()
+{
+    check_counter("common");
+    return common_;
+}
+
 vmp::str JrpReq::type()
 {
+    check_counter("type");
     return type_;
 }
 
 event::Cell *JrpReq::cell()
 {
+    check_counter("cell");
     return cell_;
 }
 
 vmp_index JrpReq::rid()
 {
+    check_counter("rid");
     return rid_;
 }
 
 vmp::str JrpReq::key()
 {
+    check_counter("key");
     return key_;
 }
 
 json::Json *JrpReq::jdata_json()
 {
+    check_counter("jdata_json");
     return &jdata_;
 }
 
 json::JsonObj *JrpReq::jdata_root()
 {
+    check_counter("jdata_root");
     return jdata_.root();
 }
 
 vmp::str JrpReq::jdata_type()
 {
+    check_counter("jdata_type");
     json::JData jdata;
     jdata.set(jdata_.root());
     return jdata.jtype();
@@ -152,6 +166,7 @@ vmp::str JrpReq::jdata_type()
 
 vmp_int JrpReq::status()
 {
+    check_counter("status");
     if(isclosed_)
         return status_;
     return 1;
@@ -159,6 +174,7 @@ vmp_int JrpReq::status()
 
 vmp::str JrpReq::msg()
 {
+    check_counter("msg");
     if(isclosed_)
         return msg_;
     return "open";
@@ -230,6 +246,7 @@ vmp_index JrpReq::release()
 
 void JrpReq::push(json::JsonObj *outputs,vmp::Buf *payload)
 {
+    check_counter("push");
     vmp::Buf buf;
     event::Manager *manager=get_manager();
     manager->lock();
@@ -249,6 +266,7 @@ void JrpReq::push(json::JsonObj *outputs,vmp::Buf *payload)
 
 void JrpReq::response(json::JsonObj *outputs,vmp::Buf *payload)
 {
+    check_counter("response");
     vmp::Buf buf;
     event::Manager *manager=get_manager();
     manager->lock();
@@ -268,6 +286,7 @@ void JrpReq::response(json::JsonObj *outputs,vmp::Buf *payload)
 
 void JrpReq::kill()
 {
+    check_counter("kill");
     vmp::Buf buf;
     event::Manager *manager=get_manager();
     manager->lock();
@@ -289,6 +308,7 @@ void JrpReq::kill()
 
 void JrpReq::close(vmp_int status,vmp::str msg)
 {
+    check_counter("close");
     vmp::Buf buf;
     event::Manager *manager=get_manager();
     manager->lock();
@@ -305,8 +325,8 @@ void JrpReq::close(vmp_int status,vmp::str msg)
         jrp::close(&buf,rid_,status_,msg_);
         crypto::EventSsl *ssl=cell_->event<crypto::EventSsl>();
         ssl->evt_ssl_send(&buf);
-        kill_end();
         release_internal();
+        kill_end();
         jrp::EventJrp *jrp=(jrp::EventJrp *)ssl->sub_;
         jrp::JrpReq *tmp;
         jrp->srvreq_.cancel(rid_,&tmp);
@@ -317,21 +337,25 @@ void JrpReq::close(vmp_int status,vmp::str msg)
 
 void JrpReq::request_oper(json::JsonObj *oper,vmp::Buf *bin)
 {
+    check_counter("request_oper");
     json::japi_oper(oper,key_,jdata_.root(),bin);
 }
 
 void JrpReq::push_oper(json::JsonObj *oper,json::JsonObj *jdata,vmp::Buf *bin)
 {
+    check_counter("push_oper");
     json::japi_oper(oper,key_,jdata,bin);
 }
 
 void JrpReq::kill_oper(json::JsonObj *oper)
 {
+    check_counter("kill_oper");
     japi_oper_kill(oper,key_);
 }
 
 void JrpReq::send_from_oper(json::JsonObj *oper)
 {
+    check_counter("send_from_oper");
     json::JData jdata;
     jdata.set(oper);
     vmp::Buf payload;
@@ -356,6 +380,7 @@ void JrpReq::send_from_oper(json::JsonObj *oper)
 
 void JrpReq::recv_close(vmp_int status,vmp::str msg)
 {
+    check_counter("recv_close");
     if(!isclosed_)
     {
         if(type_ == "")
