@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 16/05/2022
+   Date last update: 04/12/2024
 */
 
 #include "json.h"
@@ -25,12 +25,12 @@ namespace vampiria { namespace json {
 
 void primitive_error(vmp::str label)
 {
-    vmp::except("primitive '%s' bad values",label.c_str());
+    vmp::except("primitive '%s' bad value",label.c_str());
 }
 
 void set_primitive_error(vmp::str label)
 {
-    vmp::except("set primitive '%s' bad values",label.c_str());
+    vmp::except("set primitive '%s' bad value",label.c_str());
 }
 
 JData::JData()
@@ -276,13 +276,11 @@ void JData::new_list(vmp::str label,json::JList *list,vmp::str jtype)
     list->set(obj,jtype);
 }
 
-void JData::set_list(vmp::str label,json::JList *list,vmp::str jtype)
+void JData::set_list(vmp::str label,json::JList *list)
 {
     vmp::except_check_pointer((void *) list,"json::JData::set_list(list=Null)");
     if(list->list_ == 0)
         vmp::except_check_pointer((void *) list,"json::JData::set_list() input list not setting");    
-    if((jtype != "") && (jtype != list->jdata_type()))
-        vmp::except_s("json::JData::set_list() input list bad type");
     json::JsonObj jbody;
     get_jbody("set_list",&jbody);
     jbody.add_object_ex(label,list->list_);
@@ -317,13 +315,11 @@ void JData::new_table(vmp::str label,json::JTable *table,vmp::str jtype)
     table->set(obj,jtype); 
 }
         
-void JData::set_table(vmp::str label,json::JTable *table,vmp::str jtype)
+void JData::set_table(vmp::str label,json::JTable *table)
 {
     vmp::except_check_pointer((void *) table,"json::JData::set_table(table=Null)");
     if(table->table_ == 0)
         vmp::except_check_pointer((void *) table,"json::JData::set_table() input table not setting");    
-    if((jtype != "") && (jtype != table->jdata_type()))
-        vmp::except_s("json::JData::set_table() input table bad type");
     json::JsonObj jbody;
     get_jbody("set_table",&jbody);
     jbody.add_object_ex(label,table->table_);
@@ -436,7 +432,7 @@ void JData::get_custom(vmp::str label,json::JsonObj *obj)
     }
 }
 
-void JData::set_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
+void JData::set_subtype(vmp::str label,json::JsonObj *jdata)
 {
     vmp::except_check_pointer((void *) jdata,"json::JData::set_subtype(jdata=Null)");
     json::JData j;
@@ -445,8 +441,6 @@ void JData::set_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
     try
     {
         j.set(jdata);
-        if((jtype != "") && (j.jtype() != jtype))
-            json::set_primitive_error(label);
         jbody.add_object_ex(label,jdata);
     }
     catch(vmp::exception &x)
@@ -455,7 +449,7 @@ void JData::set_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
     }
 }
 
-void JData::get_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
+void JData::get_subtype(vmp::str label,json::JsonObj *jdata)
 {
     vmp::except_check_pointer((void *) jdata,"json::JData::get_subtype(jdata=Null)");
     json::JData j;
@@ -465,8 +459,6 @@ void JData::get_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
     {
         jbody.get_object(label,jdata);
         j.set(jdata);
-        if((jtype != "") && (j.jtype() != jtype))
-            json::primitive_error(label);
     }
     catch(vmp::exception &x)
     {
