@@ -94,7 +94,8 @@ void JList::push(json::JsonObj *jdata)
         tmp.set(jdata);
         if((jtype_ != "") && (tmp.jtype() != jtype_))
             vmp::except_s("");
-        list_->push_array_obj_ex(jdata);	
+        list_->push_array_obj_ex(jdata);
+        get(size()-1,jdata);	
     }
     catch(vmp::exception &x)
     {
@@ -120,12 +121,13 @@ void JList::replace(vmp_index i,json::JsonObj *jdata)
     }
     if(!list_->replace_array_obj_ex(i,jdata))
         vmp::except_s("json::JList::replace() index out bound range");
+    get(i,jdata);
 }
          
 void JList::get(vmp_index i,json::JsonObj *jdata)
 {
     check_init("get");
-    vmp::except_check_pointer((void *) jdata,"json::JList::get() null input pointer jdata");
+    vmp::except_check_pointer((void *) jdata,"json::JList::gep() null input pointer jdata");
     if(!list_->get_array_idx(i,jdata))
         vmp::except_s("json::JList::get() index out bound range");
 }
