@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 18/09/2021
+   Date last update: 18/09/2024
  */
 
 #include "json.h"
@@ -51,22 +51,24 @@ void Json::check_null_input_obj(json::JsonObj *obj,vmp::str fname)
 
 void Json::parse(vmp::str str)
 {
-    reset();
     enum json_tokener_error jerr;
     json_object *jobj = 0;
+    if(str.size() == 0)
+        vmp::except_s("json::Json::Parse(str="")");
     struct json_tokener *tok=json_tokener_new();
     do 
     {
-        jobj= json_tokener_parse_ex(tok,str.c_str(),str.size());
+        jobj=json_tokener_parse_ex(tok,str.c_str(),str.size());
     } while ((jerr = json_tokener_get_error(tok)) == json_tokener_continue);
     if (jerr != json_tokener_success)
     {
         vmp::str err=json_tokener_error_desc(jerr);
         json_tokener_reset(tok);
         json_object_put(jobj);
-        vmp::except_s(err);
+        vmp::except("json::Json::parse() %s",err.c_str());
     }
     json_tokener_reset(tok);
+    reset();
     ref_=jobj;
     root_->ref_=ref_;
 }
@@ -168,10 +170,15 @@ void Json::json_to_file(vmp::str filepath)
 
 JsonObj::JsonObj()
 {
-    ref_=0;
+    reset();
 }
         
 JsonObj::~JsonObj()
+{
+    reset();
+}
+
+void JsonObj::reset()
 {
     ref_=0;
 }
