@@ -13,10 +13,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Author: Marco Guastella alias Vasta 
+ * Author: Marco Guastella alias Vasta net::Address::
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 25/09/2022
+ * Date last update: 20/01/2024
  */
 
 #include "net.h"
@@ -111,7 +111,7 @@ vmp_bool is_ipv6_raw_frag(vmp::str ip,vmp_size *size)
        for(vmp_index i=0;i<n;i++)
        {
            l=split[i].size();
-           if(l>0 && l<=4 && vmp::unicode::str_isxdigit(split[i]))
+           if(l>0 && l<=4 && vmp::unicode::str_istype(split[i],"xdigit"))
 	       (*size) +=1;	
            else
                return false;
@@ -205,6 +205,7 @@ void Address::reset()
     host_="";
     ip_="";
     service_="";
+    onlyhost_=false;
 }
 
 void Address::init()
@@ -251,7 +252,7 @@ void Address::init_s()
     service_=sbuf;        
 }
 
-void Address::set(vmp::str host,vmp::str service)
+void Address::set(vmp::str host,vmp::str service,vmp_bool onlyhost)
 {
     reset();
     try
@@ -263,37 +264,45 @@ void Address::set(vmp::str host,vmp::str service)
         vmp::except("net::Address::set(service='%s') invalid service input",service.c_str());
     }
     service_=service;
-    if(net::is_ip_raw(host) || (dnstype_ == "system"))
+    if(onlyhost)
     {
         host_=host;
-        init();
+        onlyhost_=onlyhost;
     }
-    else 
+    else
     {
-        vmp::vector<vmp::str> resolve;
-        if(dnstype_ == "tcp4")
-            resolve=net::tcp_resolve4(host,dnsip_,dnsport_,dnstout_);
-        else if(dnstype_ == "tcp6")
-            resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
-        else if(dnstype_ == "tcp46")
+        if(net::is_ip_raw(host) || (dnstype_ == "system"))
         {
-            resolve=net::tcp_resolve4(host,dnsip_,dnsport_,dnstout_);
-            if(resolve.size() == 0)
-                resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
+            host_=host;
+            init();
         }
-        else if(dnstype_ == "tcp64")
+        else 
         {
-            resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
-            if(resolve.size() == 0)
+            vmp::vector<vmp::str> resolve;
+            if(dnstype_ == "tcp4")
                 resolve=net::tcp_resolve4(host,dnsip_,dnsport_,dnstout_);
+            else if(dnstype_ == "tcp6")
+                resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
+            else if(dnstype_ == "tcp46")
+            {
+                resolve=net::tcp_resolve4(host,dnsip_,dnsport_,dnstout_);
+                if(resolve.size() == 0)
+                    resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
+            }
+            else if(dnstype_ == "tcp64")
+            {
+                resolve=net::tcp_resolve6(host,dnsip_,dnsport_,dnstout_);
+                if(resolve.size() == 0)
+                resolve=net::tcp_resolve4(host,dnsip_,dnsport_,dnstout_);
+            }
+            if(resolve.size() == 0)
+                vmp::except("net::Address::set(host='%s') not resolve host",host.c_str()); 
+            host_=resolve[0];
+            init();
+            host_=host;
         }
-        if(resolve.size() == 0)
-            vmp::except("net::Address::set(host='%s') not resolve host",host.c_str()); 
-        host_=resolve[0];
-        init();
-        host_=host;
+        init_s();
     }
-    init_s();
 }
 
 void Address::set(net::Sockaddr *addr,vmp_size addrsize)
@@ -335,10 +344,49 @@ void Address::set_ip_raw(vmp::str ip,vmp::str service)
 
 void Address::copy(Address *address)
 {
-    if(address -> host() != "")
-       set(address->host(),address->service());
+    struct addrinfo *src,*dst,*prev;
+    if(address != 0)
+    {
+        if(addrinfo_ != 0)
+        {    
+            freeaddrinfo(addrinfo_);
+            addrinfo_=0;
+        }
+        if(address->addrinfo_ != 0)
+        {
+            src=address->addrinfo_;
+            while(src != 0)
+            {
+                dst=(struct addrinfo *) vmp::malloc_wrap(sizeof(struct addrinfo));
+                vmp::bzero_wrap((void *)dst,sizeof(struct addrinfo));
+                dst->ai_next=0;
+                dst->ai_flags = src->ai_flags; 
+                dst->ai_family = src->ai_family;
+                dst->ai_socktype = src->ai_socktype;
+                dst->ai_protocol = src->ai_protocol;
+                dst->ai_canonname = src->ai_canonname;
+                dst->ai_addrlen = src->ai_addrlen;
+                dst->ai_addr = (struct sockaddr *) vmp::malloc_wrap(src->ai_addrlen);
+                vmp::memcpy_wrap((void *)dst->ai_addr,(void *)src->ai_addr,src->ai_addrlen);
+                if(addrinfo_ == 0)
+                    addrinfo_=dst;
+                else
+                    prev->ai_next=dst;
+                prev=dst;
+                src=src->ai_next;
+            }
+        }   
+        host_=address->host_;
+        ip_=address->ip_;
+        service_=address->service_;
+        dnstype_=address->dnstype_;
+        dnsip_=address->dnsip_;
+        dnsport_=address->dnsport_;
+        dnstout_=address->dnstout_;
+        onlyhost_=address->onlyhost_;        
+    }
     else
-       reset();
+        reset();
 }
 
 net::Sockaddr *Address::addr()
@@ -362,6 +410,8 @@ vmp::str Address::host()
 
 vmp::str Address::ip()
 {
+    if(onlyhost_)
+        vmp::except("net::Address::ip() host=%s setting in onlyhost mode",host_.c_str());
     return ip_;
 }
         
@@ -407,9 +457,14 @@ vmp_bool Address::is_ipv4()
         
 vmp_bool Address::is_ipv6()
 {
-   if(iptype() == AF_INET6)
-       return true;
-   return false;
+    if(iptype() == AF_INET6)
+        return true;
+    return false;
+}
+
+vmp_bool Address::is_onlyhost()
+{
+    return onlyhost_;    
 }
 
 void ip_to_buf(net::Address *address,vmp::Buf *buf)
