@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 10/04/2022
+ * Date last update: 01/03/2024
  */
  
 #include "net.h"
@@ -166,30 +166,49 @@ vmp::vector<vmp::str> read_answers(vmp::Buf *buf,vmp_bool length)
     return ret;
 }
 
+//!Internal usage
+vmp_bool tcp_resolve(vmp::Buf *buf,vmp::str dnsip,vmp::str dnsport,vmp::time::Time timeout)
+{
+    vmp_int stream;
+    if(net::is_ipv4_raw(dnsip))
+        stream=AF_INET;
+    else if(net::is_ipv6_raw(dnsip))
+        stream=AF_INET6;
+    else
+        return false;
+    net::Address dns;
+    dns.set(dnsip,dnsport);
+    net::Socket sock=net::socket_stream(stream,true);
+    if(sock == -1)
+        return false;
+    try
+    {
+        if(net::socket_connect(sock,&dns) != 0)
+            vmp::except_s("");
+        if(net::socket_send(sock,buf) == -1)
+           vmp::except_s("");
+        net::socket_timeout(sock,timeout);
+        if(net::socket_recv(sock,buf) == 0)
+            vmp::except_s("");
+    }
+    catch(vmp::exception &x)
+    {
+        socket_close(&sock);
+        return false;
+    }
+    socket_close(&sock);
+    return true;
+}
+
 vmp::vector<vmp::str> tcp_resolve4(vmp::str host,vmp::str dnsip,vmp::str dnsport,vmp::time::Time timeout)
 {
     vmp::vector<vmp::str> ret;
     vmp::Buf buf;
-    try
-    {
-        if((!net::is_ipv4_raw(dnsip)) && (!net::is_ipv6_raw(dnsip)))
-            vmp::except_s("");
-        net::make_header(&buf);
-        net::make_qname(&buf,host,1);
-        net::make_length(&buf);
-        net::TcpClient request;
-        net::Address dns;
-        dns.set(dnsip,dnsport);
-        request.connect(&dns);
-        request.sendData(&buf);
-        net::socket_timeout(request.socket(),timeout);
-        if(request.recvData(&buf) > 0)
-            ret=net::read_answers(&buf,true);
-        request.close();
-    }
-    catch(vmp::exception &x)
-    {
-    }
+    net::make_header(&buf);
+    net::make_qname(&buf,host,1);
+    net::make_length(&buf);
+    if(net::tcp_resolve(&buf,dnsip,dnsport,timeout))
+        ret=net::read_answers(&buf,true);
     return ret;
 }
 
@@ -197,26 +216,11 @@ vmp::vector<vmp::str> tcp_resolve6(vmp::str host,vmp::str dnsip,vmp::str dnsport
 {
     vmp::vector<vmp::str> ret;
     vmp::Buf buf;
-    try
-    {
-        if((!net::is_ipv4_raw(dnsip)) && (!net::is_ipv6_raw(dnsip)))
-            vmp::except_s("");
-        net::make_header(&buf);
-        net::make_qname(&buf,host,28);
-        net::make_length(&buf);
-        net::TcpClient request;
-        net::Address dns;
-        dns.set(dnsip,dnsport);
-        request.connect(&dns);
-        request.sendData(&buf);
-        net::socket_timeout(request.socket(),timeout);
-        if(request.recvData(&buf) > 0)
-            ret=net::read_answers(&buf,true);
-        request.close();
-    }
-    catch(vmp::exception &x)
-    {
-    }
+    net::make_header(&buf);
+    net::make_qname(&buf,host,28);
+    net::make_length(&buf);
+    if(net::tcp_resolve(&buf,dnsip,dnsport,timeout))
+        ret=net::read_answers(&buf,true);
     return ret;    
 }
 
@@ -224,26 +228,11 @@ vmp::vector<vmp::str> tcp_resolveMX(vmp::str host,vmp::str dnsip,vmp::str dnspor
 {
     vmp::vector<vmp::str> ret;
     vmp::Buf buf;
-    try
-    {
-        if((!net::is_ipv4_raw(dnsip)) && (!net::is_ipv6_raw(dnsip)))
-            vmp::except_s("");
-        net::make_header(&buf);
-        net::make_qname(&buf,host,15);
-        net::make_length(&buf);
-        net::TcpClient request;
-        net::Address dns;
-        dns.set(dnsip,dnsport);
-        request.connect(&dns);
-        request.sendData(&buf);
-        net::socket_timeout(request.socket(),timeout);
-        if(request.recvData(&buf) > 0)
-            ret=net::read_answers(&buf,true);
-        request.close();
-    }
-    catch(vmp::exception &x)
-    {
-    }
+    net::make_header(&buf);
+    net::make_qname(&buf,host,15);
+    net::make_length(&buf);
+    if(net::tcp_resolve(&buf,dnsip,dnsport,timeout))
+        ret=net::read_answers(&buf,true);
     return ret;    
 }
 
