@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 01/03/2024
+ * Date last update: 24/10/2024
  */
 
 #ifndef VAMPIRIA_NET_UDP_H
@@ -92,7 +92,7 @@ class UdpUI:public event::UI
             @param proxy proxy information,if use proxy
             @return cell associated with event or except in case of failure
         */
-        event::Cell *new_client(net::Address *peer,net::ProxyInfo *proxy=0);
+        event::Cell *new_client(net::Address *peer,net::ProxyChain *proxy=0);
         
         //! Send datagram packet,for bin connection
         /*!
@@ -135,9 +135,9 @@ class UdpUI:public event::UI
         //! Gets peer proxy info(for client connection)
         /*!
             @param cell cell associated
-            @return proxy info or except in case of failure
+            @return proxy chain or except in case of failure
         */
-        net::ProxyInfo *proxyinfo(event::Cell *cell);
+        net::ProxyChain *proxychain(event::Cell *cell);
 
         //! Gets connection type(see EventConnection)
         /*!
@@ -152,6 +152,12 @@ class UdpUI:public event::UI
             @return connection type
         */
         vmp::str connection_strtype(event::Cell *cell);
+        
+        //! Last udp fragment received, used for proxies
+        /*!
+            @return fragment byte
+        */
+        vmp_byte lastfrag(event::Cell *cell);
 };
 
 }}
