@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 23/01/2020
+   Date last update: 30/05/2024
  */
 
 #ifndef VAMPIRIA_PYLIB_CONVERTER_H
@@ -57,6 +57,18 @@ pylib::Objref *Converter<vmp_uchar>(vmp_uchar value,vmp_bool retfree);
 template<>
 pylib::Objref *Converter<vmp_uchar *>(vmp_uchar *value,vmp_bool retfree);
 
+template<>
+pylib::Objref *Converter<vmp_int16>(vmp_int16 value,vmp_bool retfree);
+
+template<>
+pylib::Objref *Converter<vmp_int16 *>(vmp_int16 *value,vmp_bool retfree);
+
+template<>
+pylib::Objref *Converter<vmp_uint16>(vmp_uint16 value,vmp_bool retfree);
+
+template<>
+pylib::Objref *Converter<vmp_uint16 *>(vmp_uint16 *value,vmp_bool retfree);
+
 template<>
 pylib::Objref *Converter<vmp_int>(vmp_int value,vmp_bool retfree);
 
@@ -70,16 +82,16 @@ template<>
 pylib::Objref *Converter<vmp_uint *>(vmp_uint *value,vmp_bool retfree);
 
 template<>
-pylib::Objref *Converter<vmp_int16>(vmp_int16 value,vmp_bool retfree);
+pylib::Objref *Converter<vmp_int64>(vmp_int64 value,vmp_bool retfree);
 
 template<>
-pylib::Objref *Converter<vmp_int16 *>(vmp_int16 *value,vmp_bool retfree);
+pylib::Objref *Converter<vmp_int64 *>(vmp_int64 *value,vmp_bool retfree);
 
 template<>
-pylib::Objref *Converter<vmp_uint16>(vmp_uint16 value,vmp_bool retfree);
+pylib::Objref *Converter<vmp_uint64>(vmp_uint64 value,vmp_bool retfree);
 
 template<>
-pylib::Objref *Converter<vmp_uint16 *>(vmp_uint16 *value,vmp_bool retfree);
+pylib::Objref *Converter<vmp_uint64 *>(vmp_uint64 *value,vmp_bool retfree);
 
 template<>
 pylib::Objref *Converter<vmp_real>(vmp_real value,vmp_bool retfree);
