@@ -15,7 +15,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/01/2023
+   Date last update: 01/02/2024
  */
 
 #include <assert.h>
@@ -85,7 +85,13 @@ void except_args(const vmp_char *fmt,...);
 //!throws alloc exception
 void except_alloc();
 
-//! Get errno error
+//! Get errno value
+/*!
+    @return errno value
+*/
+vmp_int get_errno();
+
+//! Get errno error(string mode)
 /*!
     @return string error associated with errno
 */
