@@ -16,13 +16,98 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/01/2023
+   Date last update: 10/05/2024
  */
 
 #include "vmp.h"
 
 namespace vampiria { namespace vmp {
 
+vmp::File fopen_wrap(vmp::str pathname,vmp::str mode)
+{
+    vmp::File file=fopen(pathname.c_str(),mode.c_str());
+    if(file == 0)
+        vmp::except("'%s' %s",pathname.c_str(),vmp::strerror_wrap(errno).c_str());
+    return file;
+}
+
+vmp::File fdopen_wrap(vmp_int fd,vmp::str mode)
+{
+    vmp_assert(_POSIX_C_SOURCE);
+    vmp::File ret=fdopen(fd,mode.c_str());
+    if(ret == 0)
+        vmp::except_errno();
+    return ret;
+}
+
+vmp_int fgetc_wrap(vmp::File file)
+{
+    vmp::except_check_pointer((void *) file,"vmp::fgetc_wrap (file=null)");
+    return fgetc(file);
+}
+
+void fflush_wrap(vmp::File file)
+{
+    vmp::except_check_pointer((void *) file,"vmp::fflush_wrap(file=null)");
+    if(fflush(file) != 0)
+        vmp::except_errno();
+}
+
+void fseek_wrap(vmp::File file,vmp_uint offset,vmp::str whence)
+{
+    vmp::except_check_pointer((void *) file,"vmp::fseek_wrap(file=null)");
+    vmp_int w;
+    if(whence == "set")
+        w=SEEK_SET;
+    else if(whence == "cur")
+        w=SEEK_CUR;
+    else if(whence == "end")
+        w=SEEK_END;
+    else
+        vmp::except("vmp::fseek(whence='%s') bad value",whence.c_str());
+    if(fseek(file,(vmp_int) offset,w) == -1)
+        vmp::except_errno();
+}
+
+vmp_index ftell_wrap(vmp::File file)
+{
+    vmp::except_check_pointer((void *) file,"vmp::ftell_wrap(file=null)");
+    vmp_int ret=ftell(file);
+    if(ret == -1)
+        vmp::except_errno();
+    return (vmp_index) ret;
+}
+
+vmp_size fread_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file)
+{
+    vmp::except_check_pointer(ptr,"vmp::fread_wrap(ptr=null)");
+    vmp::except_check_pointer((void *) file,"vmp::fread_wrap(file=null)");
+    clearerr(file);
+    vmp_size ritems=fread(ptr,size,nmemb,file);
+    if(ferror(file) != 0)
+        vmp::except_errno();
+    return ritems;
+}
+
+vmp_size fwrite_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file)
+{
+    vmp::except_check_pointer(ptr,"vmp::fread_wrap(ptr=null)");
+    vmp::except_check_pointer((void *) file,"vmp::fwrite_wrap(file=null)");
+    vmp_size ritems=fwrite(ptr,size,nmemb,file);
+    if(ritems < nmemb)
+        vmp::except_errno();
+    return ritems;
+}
+
+void fclose_wrap(vmp::File *pfile)
+{
+    if((*pfile) != 0)
+    {
+        fclose(*pfile);
+        (*pfile)=0;
+    }
+}
+
 static vmp_bool debug_=false;
 static vmp::str id_="None";
 static vmp::thread::Mutex iomutex_;
@@ -159,13 +244,13 @@ void error_raw(const vmp_char *fmt,...)
     va_start(ap,fmt);    
     vmp::str sfmt=vmp::va_wrap(fmt,ap);
     va_end(ap);
-    error_raw_s(sfmt);
+    vmp::error_raw_s(sfmt);
 }
 
 void output_s(vmp::str msg)
 {
     iomutex_.lock();
-    std::cout << msg << std::endl; 
+    std::cout << msg << std::endl;
     iomutex_.unlock();
 }
 
@@ -202,18 +287,16 @@ void output_file_s(vmp::str filename,vmp_bool newfile,vmp::str msg)
 
 void output_file(vmp::str filename,vmp_bool newfile,const vmp_char *fmt,...)
 {
-    FILE *file;
+    vmp::File file;
     if(newfile)
-        file=fopen(filename.c_str(),"w+");
+        file=vmp::fopen_wrap(filename,"w+");
     else
-        file=fopen(filename.c_str(),"a+");
-    if(file == 0)
-        vmp::except("'%s' %s",filename.c_str(),vmp::strerror_wrap(errno).c_str());
+        file=vmp::fopen_wrap(filename,"a+");
     va_list ap;
     va_start(ap,fmt);    
     vfprintf(file,fmt,ap);
     va_end(ap);
-    fclose(file);
+    vmp::fclose_wrap(&file);
 }
 
 void output_file_lines(vmp::str filename,vmp_bool newfile,vmp::vector<vmp::str> lines)
@@ -226,7 +309,7 @@ void output_file_lines(vmp::str filename,vmp_bool newfile,vmp::vector<vmp::str>
         else
             vmp::unicode::str_cwrite(&msg,"%s",lines[i]);
     }
-    output_file(filename,newfile,"%s",msg.c_str());
+    vmp::output_file(filename,newfile,"%s",msg.c_str());
 }
 
 static vmp::str streamcin_="";
@@ -235,7 +318,7 @@ vmp::str input()
 {
     vmp_byte c;
     vmp_int result;
-    while((result=fd_read_bytes(0,&c,1)) == 1)
+    while((result=vmp::fd_read_bytes(0,&c,1)) == 1)
     {
         if(c == '\n')
         {
@@ -255,13 +338,11 @@ vmp::str input()
 vmp::vector<vmp::str> input_file(vmp::str filename)
 {
     vmp::vector<vmp::str> ret;
-    FILE *file=fopen(filename.c_str(),"r");
+    vmp::File file=vmp::fopen_wrap(filename,"r");
     vmp_int c;
     vmp_byte b;
-    if(file == 0)
-        vmp::except("'%s' %s",filename.c_str(),vmp::strerror_wrap(errno).c_str());
     vmp::str str="";
-    while((c=fgetc(file)) != EOF)
+    while((c=vmp::fgetc_wrap(file)) != EOF)
     {
        b=(vmp_byte)c;
        if(b == '\n')
@@ -275,24 +356,22 @@ vmp::vector<vmp::str> input_file(vmp::str filename)
     }
     if(str.size() != 0)
        ret.push_back(str);
-    fclose(file);
+    vmp::fclose_wrap(&file);
     return ret;
 }
 
 vmp::str input_file_s(vmp::str filename)
 {
     vmp::str ret="";
-    FILE *file=fopen(filename.c_str(),"r");
+    vmp::File file=vmp::fopen_wrap(filename,"r");
     vmp_int c;
     vmp_byte b;
-    if(file == 0)
-        vmp::except("'%s' %s",filename.c_str(),vmp::strerror_wrap(errno).c_str());
-    while((c=fgetc(file)) != EOF)
+    while((c=vmp::fgetc_wrap(file)) != EOF)
     {
         b=(vmp_byte)c;
         ret+=b;
     }
-    fclose(file);
+    vmp::fclose_wrap(&file);
     return ret;
 }
 
@@ -315,29 +394,23 @@ void exit_failure(const vmp_char *fmt,...)
     exit_failure_s(sfmt);
 }
 
-FILE *fd_stream(vmp_int fd) 
+vmp::File fd_stream(vmp_int fd) 
 {
-    vmp_assert(_POSIX_C_SOURCE);
-    FILE *ret=fdopen(fd,"w");
-    if(ret == 0)
-        vmp::except_errno();
-    return ret;
+    return fdopen_wrap(fd,"w");
 }
 
-void stream_write(FILE *f,vmp::str data)
+void stream_write(vmp::File f,vmp::str data)
 {
     if(f == 0)
        return;
     if(fprintf(f,"%s",data.c_str()) < 0)
        vmp::except_errno();
-    fflush(f);
+    vmp::fflush_wrap(f);
 }
 
 void stream_close(FILE **f)
 {
-    if((*f) != 0)
-       fclose((*f));
-    (*f)=0;
+    vmp::fclose_wrap(f);
 }
 
 void copy_file(vmp::str src,vmp::str dst)
