@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/01/2023
+   Date last update: 10/05/2024
  */
 
 #include <stdio.h>
@@ -29,6 +29,81 @@
 
 namespace vampiria { namespace vmp {
 
+//! File descriptor
+typedef FILE * File;
+
+//! Opens the file whose name is the string pointed to by pathname and associates a stream with it
+/*!
+    @param pathname file path
+    @mode mode see man linux fopen
+    @return file stream or except in case of failure
+*/
+vmp::File fopen_wrap(vmp::str pathname,vmp::str mode);
+
+//! Associates a stream with the existing file descriptor
+/*!
+    @param fd file descriptor
+    @mode mode see man linux fopen
+    @return file stream or except in case of failure
+*/
+vmp::File fdopen_wrap(vmp_int fd,vmp::str mode);
+
+//! Reads the next character from stream 
+/*!
+    @param file file stream
+    @return it as an vmp_uint cast to an vmp_int,or EOF on end or ecept in case of failure
+*/
+vmp_int fgetc_wrap(vmp::File file);
+
+//! For output streams,fflush() forces a write of all userspace buffered data
+/*!
+    @param file file stream
+    @return void or except in case of failure
+*/
+void fflush_wrap(vmp::File file);
+
+//! Sets the file position indicator for the stream pointed to by file
+/*!
+    @param file file stream
+    @param offset adding  offset bytes to the position specified by whence
+    @param whence "set"(start file),"cur"(current position),"end"(end file)
+    @return void or except in case of failure
+*/
+void fseek_wrap(vmp::File file,vmp_uint offset,vmp::str whence);
+
+//! Obtains the current value of the  file  position indicator for the stream pointed to by file
+/*!
+    @param file file stream
+    @return stream position or except in case of failure
+*/
+vmp_index ftell_wrap(vmp::File file);
+
+//! Reads nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
+/*!
+    @param ptr pointer to stored data
+    @param size size item
+    @param nmenb number item
+    @param file file stream
+    @return number nmemb reads or except in case of failure
+*/
+vmp_size fread_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);
+
+//! Writs nmemb items of data, each size bytes long,from the stream pointed to by stream, storing them  at  the  location given by ptr
+/*!
+    @param ptr pointer to read data
+    @param size size item
+    @param nmenb number item
+    @param file file stream
+    @return number nmemb writs or except in case of failure
+*/
+vmp_size fwrite_wrap(void *ptr,vmp_size size,vmp_size nmemb,vmp::File file);
+
+//! Close file descriptor
+/*!
+    @param pfile pointer to file descriptor
+*/
+void fclose_wrap(vmp::File *pfile);
+
 //! init process                
 /*!
     @param id process identified
@@ -231,14 +306,14 @@ void exit_failure(const vmp_char *fmt,...);
     @param fd fd input
     @return file stream or except in case of failure
 */
-FILE *fd_stream(vmp_int fd);
+vmp::File fd_stream(vmp_int fd);
 
 //! Write data in filestream
 /*!
     @param f file stream
     @param data data write(except errno)
 */
-void stream_write(FILE *f,vmp::str data);
+void stream_write(vmp::File f,vmp::str data);
 
 //!Close File stream assign (*f)=0
 /*!
