@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/05/2024
+   Date last update: 30/01/2025
  */
 
 #include <stdlib.h>
@@ -25,6 +25,7 @@
 #include <pty.h>
 #include <fcntl.h>
 #include <ctype.h>
+#include <pwd.h>
 
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -55,12 +56,13 @@ class Instance
         //! A destructor
         ~Instance();
         
-        static void *global_;/*!< Global data*/        
+        static void *global_;/*!< Global data*/
+        static void *logger_;/*!<Logger for debugging library*/
     public:
         //! Get global data
         /*!
-            \sa global_
-            \return global data
+            @sa global_
+            @return global data
         */        
 
         template<class DATA>        
@@ -71,8 +73,8 @@ class Instance
 
         //! Set global data
         /*!
-            @param data global set data            
-            \sa global_
+            @param data set global data            
+            @sa global_
             
         */
         template<class DATA>        
@@ -80,6 +82,29 @@ class Instance
         {
             global_=(void *) data;
         }
+        
+        //! Get logger
+        /*!
+            @sa logger_
+            @return logger data
+        */        
+        template<class DATA>        
+        static DATA *get_logger() 
+        {
+            return (DATA *) logger_;
+        } 
+
+        //! Set logger
+        /*!
+            @param data set logger            
+            @sa global_
+            
+        */
+        template<class DATA>        
+        static void set_logger(DATA *data)
+        {
+            logger_=(void *) data;
+        }
 };
 
 }}
