@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/02/2024
+   Date last update: 13/11/2024
  */
 
 #include "vmp.h"
@@ -148,7 +148,7 @@ vmp_bool Localtime::day_check(vmp_int year_v,vmp_int month_v,vmp_int day_v)
 void Localtime::croniter_expand(vmp::vector<vmp_uint> *ret,vmp::str expr,vmp_int min,vmp_int max)
 {
     vmp::vector<vmp::str> tmp;
-    vmp_int div=1;
+    vmp_int div=0;
     if(vmp::unicode::str_regex_matching(expr,"([0-9]+-[0-9]+|[0-9]+|\\*)/[0-9]+"))
     {
         tmp=vmp::unicode::str_split(expr,"/");
@@ -166,9 +166,12 @@ void Localtime::croniter_expand(vmp::vector<vmp_uint> *ret,vmp::str expr,vmp_int
 	else
 	{
 	    min=vmp::unicode::str_todigit_range(expr,min,max);
-	    max=min;    
+	    if(div == 0)
+	        max=min;
 	}
     }
+    if(div == 0)
+        div=1;
     for(vmp_int i=min;i<=max;i=i+div)
         ret->push_back(i);
 }
@@ -663,6 +666,15 @@ vmp_uint Localtime::year_day()
     return ret+tm_.tm_mday;
 }
 
+vmp_bool Localtime::summertime()
+{
+    if(tm_.tm_isdst < 0)
+        vmp::except_s("Localtime::summertime() information is not available");
+    if(tm_.tm_isdst > 0)
+        return true;
+    return false;
+}
+
 Timer::Timer()
 {
     init();    
@@ -684,7 +696,6 @@ vmp::time::Time Timer::now()
     vmp::time::Time s=(vmp::time::Time)(now.tv_sec -tinit_.tv_sec);
     vmp::time::Time us=(((vmp::time::Time)(now.tv_usec))-((vmp::time::Time)(tinit_.tv_usec)))/1000000; 
     return s+us; 
-    
 }
 
 }}}
