@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/04/2024
+   Date last update: 16/01/2025
  */
 
 #ifndef VAMPIRIA_VMP_UTILS_H
@@ -184,6 +184,20 @@ class Logger
 
         //! Reset logger        
         void reset();
+        
+        //! Returns file log path
+        /*!
+            @sa logname_
+            @return file log path
+        */
+        vmp::str logname();
+        
+        //! Returns file log level
+        /*!
+            @sa loglevel_
+            @return file log level
+        */
+        vmp_byte loglevel();
 
         //! Setting logger
         /*!
@@ -228,6 +242,28 @@ const vmp_byte LOG_INFO=0x02;  /*!< Log type Info*/
 const vmp_byte LOG_WARN=0x03;  /*!< Log type Warn*/
 const vmp_byte LOG_ERR=0x04;   /*!< Log type Err*/
 
+//! Build Logger for debugging library
+/*!
+    @path syslog path
+    @return void or except in case of failure
+*/
+void syslog_build(vmp::str filepath);
+
+//! Write log file(string mode)
+/*!
+    @param facility level log data
+    @param value write data
+*/
+void syslog_s(vmp_byte facility,vmp::str value);
+
+//! Write syslog file(format mode)
+/*!
+    @param facility level log data
+    @param fmt format string
+    @param ... format args
+*/
+void syslog(vmp_byte facility,const vmp_char *fmt,...);
+
 }}
 
 }
