@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 29/12/2024
+   Date last update: 20/03/2025
  */
 /**
  *Virtual class interface for websocket login (see Vmp_Cmp_Main)<br>
@@ -63,6 +63,12 @@ class Vmp_Cmp_Waiting_I extends Vmp_Cmp_Div
   constructor()
   {
     super();
+    /**
+     *Message waiting
+     *@type {text}
+     *@public
+    */
+    this.msg_="";
     /**
      *waiting timer
      *@type {cmp}
@@ -77,6 +83,7 @@ class Vmp_Cmp_Waiting_I extends Vmp_Cmp_Div
   */
   start(msg,timeout)
   {
+    this.msg_=msg;
     this.timer_.start(()=>{vmp_wrap_alert(`Timeout:${msg}`);window.main_.timeout(msg);},timeout);
     this.view(`${msg}...`);
   }
@@ -353,7 +360,7 @@ class Vmp_Cmp_Passwd extends Vmp_Cmp_Div
     bsend.addEventListener("click",this.change.bind(this));
     let breset=vmp_cmp_button("Reset");
     this.register_cmp("breset",breset);
-    tmp.addEventListener("click",(e)=>{this.search_cmp("ipasswd").reset();this.search_cmp("inpasswd").reset();this.search_cmp("icpasswd").reset()});
+    breset.addEventListener("click",(e)=>{this.search_cmp("ipasswd").reset();this.search_cmp("inpasswd").reset();this.search_cmp("icpasswd").reset()});
     let div=vmp_cmp_div();
     div.appendChild(bsend);
     div.appendChild(breset);
@@ -363,20 +370,20 @@ class Vmp_Cmp_Passwd extends Vmp_Cmp_Div
   /**internal usage*/
   change(e)
   {
-    let tmp=this.search_cmp("ipasswd");
-    let ipasswd=tmp.get_value();
-    tmp.reset();
-    tmp=this.search_cmp("inpasswd");
-    let inpasswd=tmp.get_value();
-    tmp.reset();
-    tmp=this.search_cmp("icpasswd");
-    let icpasswd=tmp;
-    tmp.reset();
+    let ipasswd_t=this.search_cmp("ipasswd");
+    let ipasswd=ipasswd_t.get_value();
+    let inpasswd_t=this.search_cmp("inpasswd");
+    let inpasswd=inpasswd_t.get_value();
+    let icpasswd_t=this.search_cmp("icpasswd");
+    let icpasswd=icpasswd_t.get_value();
     if(inpasswd != icpasswd)vmp_wrap_alert("New and confirm passwords don't match");
     else
     {
       let jdata=vmp_japi_passwd(ipasswd,inpasswd);
       window.main_.request(this,jdata);
+      ipasswd_t.reset();
+      inpasswd_t.reset();
+      icpasswd_t.reset();
       window.main_.waiting("Change password",10000,Vmp_WebSocketCode.Protocol,"Change Password timeout");
     }
   }
@@ -554,7 +561,7 @@ class Vmp_Cmp_User extends Vmp_Cmp_Div
     {
       if(user.get_value() == '')
         vmp_wrap_alert("The user field is empty");
-      else if(password.get_value() != password.get_value())
+      else if(password.get_value() != cpassword.get_value())
         vmp_wrap_alert("Password and confirm passwords don't match");
       else
       {
@@ -597,7 +604,7 @@ class Vmp_Cmp_User extends Vmp_Cmp_Div
   {
     let list=this.search_cmp("list");
     let user=event.currentTarget.bid();
-    let row=list.lines_.get(user);
+    let row=list.lines_.get(user)['row'];
     this.search_cmp("user").set_value(user);
     this.search_cmp("permits").set_value(list.row_getcell(row,1).innerHTML);
     if(row.cells[2].innerHTML === "yes")
@@ -787,7 +794,7 @@ class Vmp_Cmp_Peer extends Vmp_Cmp_Div
   {
     let list=this.search_cmp("list");
     let fingerprint=event.currentTarget.bid();
-    let row=list.lines_.get(fingerprint);
+    let row=list.lines_.get(fingerprint)['row'];
     this.search_cmp("fingerprint").set_value(fingerprint);
     this.search_cmp("subject").set_value(list.row_getcell(row,0).innerHTML);
     this.search_cmp("permits").set_value(list.row_getcell(row,1).innerHTML);
@@ -810,6 +817,79 @@ class Vmp_Cmp_Peer extends Vmp_Cmp_Div
     this.search_cmp("permits").reset();
   }
 }
+/**
+  *Component for managing connection
+**/
+class Vmp_Cmp_ConnectStatus extends Vmp_Cmp_Div
+{
+  /**constructor*/
+  constructor()
+  {
+    super();
+    let exec=vmp_cmp_button("Connection list");
+    exec.addEventListener("click",this.oper.bind(this));
+    this.appendChild(exec);
+    let list=vmp_cmp_list({name:'id',order:true,width:'30%'},
+                          {name:'aux data',order:true,width:'25%'}, 
+                          {name:'type',order:true,width:'7%'}, 
+                          {name:'permits',order:true,width:'5%'}, 
+                          {name:'address',order:true,width:'14%'},
+                          {name:'port',order:true,width:'7%'},
+                          {name:'close',width:'7%'});
+    this.register_cmp("list",list);
+    this.appendChild(list);
+  }
+  /**internal usage*/
+  oper(event)
+  {
+    let list=this.search_cmp("list");
+    list.reset();
+    let jdata=japi_connectlist();
+    window.main_.request(this,jdata);
+    window.main_.waiting("ConnectList",10000,Vmp_WebSocketCode.Protocol,"ConnectList timeout");
+  }
+  uselect(event)
+  {
+    let list=this.search_cmp("list");
+    let id=event.currentTarget.bid();
+    let row=list.lines_.get(id)['row'];
+    if(vmp_wrap_confirm(`Confirm Close Connection: ${id}`))
+    {
+      let jdata=vmp_japi_connectclose(id,list.row_getcell(row,2).innerHTML);
+      list.reset();
+      window.main_.request(this,jdata);
+      window.main_.waiting("ConnectClose",10000,Vmp_WebSocketCode.Protocol,"Connection close timeout");
+    }
+  }
+  /**virtual function*/
+  req_recv(req,jdata,payload)
+  {
+    let list=this.search_cmp("list");
+    let id=jdata.get_text("id");
+    let type=jdata.get_text("type");
+    let aux=jdata.get_text("aux");
+    let permits=jdata.get_integer_range("permits",Vmp_jrp_min_permits,Vmp_jrp_max_permits);
+    let address=jdata.get_text("address");
+    let port=jdata.get_integer_range("port",0,65535);
+    let k=vmp_cmp_button_img(Vmp_Img.select,id,id);
+    k.addEventListener("click",this.uselect.bind(this));
+    list.insert(id,[vmp_unicode_str_format_lines(id,32),vmp_unicode_str_format_lines(aux,24),type,permits,vmp_unicode_str_format_lines(address,15),port,k]); 
+  }
+  /**virtual function*/
+  req_close(req)
+  {
+    window.main_.main();
+    let voper;
+    if(req.type_ === vmp_japi_type("connectlist"))
+      voper="Connect List";
+    else
+      voper="Connect close";
+    if(req.close_status_ === Vmp_Jrp_StatusCode.ok)
+      vmp_wrap_alert(`${voper} ok`);
+    else
+      vmp_wrap_alert(`${voper} error '${req.close_msg_}'`) 
+  }
+};
 /**
   *The default component JRP and session message management class(see Vmp_Cmp_Main)
   *@extends Vmp_Jrp_Manager_I
@@ -862,6 +942,7 @@ class Vmp_Cmp_Manager extends Vmp_Jrp_Manager_I
     this.register_cmp("passwd",vmp_wrap_createElement("vmp-passwd",'div'));
     this.register_cmp("users",vmp_wrap_createElement("vmp-user",'div'));
     this.register_cmp("peers",vmp_wrap_createElement("vmp-peer",'div'));
+    this.register_cmp("connectstatus",vmp_wrap_createElement("vmp-connectstatus",'div'));
     let body=vmp_cmp_menu();
     this.register_cmp("body",body);
     this.appendChild(body);
@@ -912,6 +993,8 @@ class Vmp_Cmp_Manager extends Vmp_Jrp_Manager_I
       body.add_section("Users",this.search_cmp("users"));
     if (vmp_japi_type("peerlist") in this.reqdata_)
       body.add_section("Peers",this.search_cmp("peers"));
+    if (vmp_japi_type("connectlist") in this.reqdata_)
+      body.add_section("Connection",this.search_cmp("connectstatus"));
   }
   /**Virtual function called on request*/
   update_request(req)
@@ -942,6 +1025,7 @@ try
   vmp_wrap_define("vmp-passwd",Vmp_Cmp_Passwd,'div');
   vmp_wrap_define("vmp-user",Vmp_Cmp_User,'div');
   vmp_wrap_define("vmp-peer",Vmp_Cmp_Peer,'div');
+  vmp_wrap_define("vmp-connectstatus",Vmp_Cmp_ConnectStatus,'div');
   vmp_wrap_define("vmp-manager",Vmp_Cmp_Manager,'div');
 }
 catch(error)
