@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 26/12/2024
+   Date last update: 26/02/2025
  */
 /**
   *decorator who transforms a tag into a component
@@ -562,7 +562,7 @@ class Vmp_Cmp_CheckBox extends vmp_component(HTMLInputElement)
     *Init Component
     *@param value {String} Checkbox value
   */
-  init(value){this.setAttribute("value","only_localhost");};
+  init(value){this.setAttribute("value",value);};
   /**virtual function*/
   enable_impl(){vmp_tag_enable(this);}
   /**virtual function*/
@@ -660,9 +660,15 @@ class Vmp_Cmp_Select extends vmp_component(HTMLSelectElement)
     }
   }
   /**virtual function*/
-  reset_impl(){this.selectedIndex="0";}
+  reset_impl(){this.set_value(0);}
+  /**virtual function*/
+  enable_impl(){vmp_tag_enable(this);}
+  /**virtual function*/
+  disable_impl(){vmp_tag_disable(this);}
   /**Return value selected*/
   get_value(){return this.value;}
+  /**Setting index value*/
+  set_value(index=0){this.selectedIndex=index;}
 };
 try
 {
@@ -1087,9 +1093,14 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
     *Inserts a line in the list
     *@param key {String} key data
     *@param data {Array} data entered
+    *@param enabled {Boolean} is the row enabled?This value is used for new entries, if the key is updated it is ignored
+    *@param aux {Object} Object not displayed in the table
   */
-  insert(key,data)
+  insert(key,data,enabled=true,aux={})
   {
+    let line=this.lines_.get(key);
+    if(line != undefined)
+      enabled=line.enabled;
     this.cancel(key);
     let row=this.tbody_row();
     let i=0;
@@ -1118,8 +1129,9 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
       let col=this.row_td(row,i++);
       this.col_style(col);
     }
-    this.lines_.set(key,row);
-    this.order(); 
+    this.lines_.set(key,{row:row,enabled:enabled,aux:aux});
+    this.order();
+    this.display();
   }
   /**
     *Delete a line from the list
@@ -1127,13 +1139,99 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
   */
   cancel(key)
   {
-    let row=this.lines_.get(key);
-    if(row != undefined)
+    let line=this.lines_.get(key);
+    if(line != undefined)
     {
-      row.remove();
+      line.row.remove();
       this.lines_.delete(key);
     }  
   }
+  /**
+    *enable lines with input keys
+    *@param keys {Array_String} input keys
+  */
+  enable(keys)
+  {
+    for(k of key)
+    {
+      let line=this.lines_.get(key);
+      if(line != undefined) 
+        line.enabled=true;
+    }
+    this.display();
+  }
+  /**
+    *Enable lines with input keys and disable everything else
+    *@param keys {Array_String} input keys
+  */
+  config_enable(keys)
+  {
+    for(const [key,value] of this.lines_)
+    {
+      if(vmp_invector(key,keys))
+        value.enabled=true;
+      else
+        value.enabled=false;
+    }
+    this.display();
+  }
+  /**
+    *Return Enabled Row Keys
+    *@return {Array_string} enabled key
+  */
+  get_enabled()
+  {
+    ret=[]
+    for(const [key,value] of this.lines_)
+    {
+      if(value.enabled)
+        ret.push(key); 
+    }
+    return ret;
+  }
+  /**
+    *Disable lines with input keys
+    *@param keys {Array_String} input keys
+  */
+  disable(keys)
+  {
+    for(k of key)
+    {
+      let line=this.lines_.get(key);
+      if(line != undefined) 
+        line.enabled=false;
+    }
+    this.display();
+  }
+  /**
+    *Disable lines with input keys and enable everything else
+    *@param keys {Array_String} input keys
+  */
+  config_disable(keys)
+  {
+    for(const [key,value] of this.lines_)
+    {
+      if(vmp_invector(key,keys))
+        value.enabled=false;
+      else
+        value.enabled=true;
+    }
+    this.display();
+  }
+  /**
+    *Return disbaledd Row Keys
+    *@return {Array_string} disabled key
+  */
+  get_disabled()
+  {
+    ret=[]
+    for(const [key,value] of this.lines_)
+    {
+      if(!value.enabled)
+        ret.push(key); 
+    }
+    return ret;
+  }
   /**Internal usage*/
   order()
   {
@@ -1147,6 +1245,17 @@ class Vmp_Cmp_List extends Vmp_Cmp_Table
       this.tbody_.append(...sortedRows);
     }
   }
+  /**Internal usage*/
+  display()
+  {
+    for(const [key,value] of this.lines_)
+    {
+      if(value.enabled)
+        value.row.style.display="table-row";
+      else
+        value.row.style.display="none";
+    }
+  }
   /**Virtual function*/
   reset_impl()
   {
@@ -1171,13 +1280,15 @@ class Vmp_Cmp_Info extends Vmp_Cmp_Table
   {
     col.style.setProperty("text-align","left");
     col.style.setProperty("padding-top","5px");
+    col.style.setProperty("padding-left","5px");
   }
   /**
     *Adds a value title pair
     *@param title {Tag_or_String} title
     *@param value {Tag_or_String} value
+    *@param cols {Size} Number of Value Columns
   **/
-  add_line(title,value)
+  add_line(title,value,cols=1)
   {
     let row=this.tbody_row();
     let col=this.row_td(row,0);
@@ -1191,6 +1302,7 @@ class Vmp_Cmp_Info extends Vmp_Cmp_Table
     }
     this.col_style(col);
     col=this.row_td(row,1);
+    col.setAttribute("colspan",cols);
     try
     {
       col.appendChild(value);
@@ -1201,15 +1313,48 @@ class Vmp_Cmp_Info extends Vmp_Cmp_Table
     }
     this.col_style(col);
   }
+  /**
+    *Adds values to the info
+    *@param title {Tag_or_String} title
+    *@param values {Array_Tag} value
+  **/
+  add_multilines(title,values)
+  {
+    let row=this.tbody_row();
+    let col=this.row_td(row,0);
+    try
+    {
+      col.appendChild(title);
+    }
+    catch(e)
+    {
+      col.innerHTML=title;
+    }
+    this.col_style(col);
+    for (let i=0; i<values.length;i++)
+    {
+      col=this.row_td(row,i+1);
+      try
+      {
+        col.appendChild(values[i]);
+      }
+      catch(e)
+      {
+        col.innerHTML=values[i];
+      }
+      this.col_style(col);
+    }
+  }
   /**
     *Adds a single value in the center
     *@param value {Tag_or_String} value
+    *@param cols {Size} Number of column it includes
   **/
-  add_single_line(value)
+  add_single_line(value,cols=2)
   {
     let row=this.tbody_row()
-    let col=this.row_td(row,0);;
-    col.setAttribute("colspan",2);
+    let col=this.row_td(row,0);
+    col.setAttribute("colspan",cols);
     try
     {
       col.appendChild(value);
@@ -1249,10 +1394,14 @@ class Vmp_Cmp_Top extends Vmp_Cmp_Table
     col.setAttribute("width","50%");
     col.setAttribute("rowspan","3");
     let center=vmp_wrap_createElement("center");
-    let tagimg=vmp_cmp_img(img,"project logo");
-    tagimg.setAttribute("width","100px");
-    tagimg.setAttribute("height","56px");
-    center.appendChild(tagimg);
+    /**
+      *Logo image
+      *@public
+    */
+    this.tagimg=vmp_cmp_img(img,"project logo");
+    this.tagimg.setAttribute("width","100px");
+    this.tagimg.setAttribute("height","56px");
+    center.appendChild(this.tagimg);
     col.appendChild(center);
     let ttitle=this.row_td(trow);
     ttitle.setAttribute("width","50%");
@@ -1318,7 +1467,7 @@ function vmp_cmp_info(){return vmp_wrap_createElement("vmp-info",'table');}
   *@param img {String} Image paths
   *@param title {String} Project title
   *@param info {Tag} Info tag
-  *@return {Tag} component info
+  *@return {Tag} component top
 */
 function vmp_cmp_top(img,title,info)
 {
