@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 04/12/2024
+   Date last update: 30/01/2025
  */
 /**Used to work with JData lists*/
 class Vmp_JList
@@ -590,7 +590,7 @@ class Vmp_JData
     {
       if(!vmp_isarray(args))
         vmp_except("Vmp_JData.set_args(args) bad value");
-      for(arg of args)
+      for(let arg of args)
       {
         if(!vmp_isstring(arg))
           vmp_except("Vmp_JData.set_args(args) bad value");
@@ -608,7 +608,7 @@ class Vmp_JData
       let args=this.get_value(label,"get_args");
       if(!vmp_isarray(args))
         vmp_except("Vmp_JData.get_args() bad return value");
-      for(arg of args)
+      for(let arg of args)
       {
         if(!vmp_isstring(arg))
           vmp_except("Vmp_JData.get_args() bad return value");
@@ -1183,3 +1183,45 @@ function vmp_japi_peerdel(fingerprint)
   ret.set_text("fingerprint",fingerprint);
   return ret;  
 }
+/**
+  *Create a json data vmp_japi_type("connectlist") used for request list peers
+  *<pre>
+  *{ 
+  *  jtype: vmp_japi_type("connectlist"),
+  *  jbody: 
+  *  {
+  *  }
+  *}
+  *</pre>
+  *@return {Vmp_JData} json data
+*/
+function japi_connectlist()
+{
+  let ret=new Vmp_JData();
+  ret.new_data(vmp_japi_type("connectlist"));
+  return ret;
+}
+/**
+  *Create a json data vmp_japi_type("connectclose") used to close connection
+  *<pre>
+  *{ 
+  *  jtype: vmp_japi_type("connectclose"),
+  *  jbody: 
+  *  {
+  *    id:'connection id',
+  *    type:'connection type (p2p or wss)',
+  *  }
+  *}
+  *</pre>
+  *@param id {String} connect id   (read data jdata.get_text("id"))
+  *@param id {String} connect type (read data jdata.get_text("type"))
+  *@return {Vmp_JData} json data
+*/
+function vmp_japi_connectclose(id,type)
+{
+  let ret=new Vmp_JData();
+  ret.new_data(vmp_japi_type("connectclose"));
+  ret.set_text("id",id);
+  ret.set_text("type",type);
+  return ret;  
+}
