@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 26/12/2024
+   Date last update: 27/01/2025
  */
 
 /**Interface component for main application*/
@@ -471,4 +471,27 @@ class Vmp_Main extends vmp_component(HTMLElement)
   */
   recv_broadcast(jdata,payload){}
 };
+/**
+  *Submit a request and wait for it to complete
+  *@param req {Vmp_Jrp_Request} request send
+*/
+function vmp_main_operwait(cmp,jdata,text)
+{
+  let ret=window.main_.request(cmp,jdata);
+  window.main_.waiting(text,10000,Vmp_WebSocketCode.Protocol,`${text} close timeout`);
+  return ret;
+}
 
+/**
+  *Close a pending request
+  *@param req {Vmp_Jrp_Request} request close
+*/
+function vmp_main_operwait_close(req)
+{
+  let voper=window.main_.search_cmp("waiting").msg_;
+  window.main_.main();
+  if(req.close_status_ === Vmp_Jrp_StatusCode.ok)
+    vmp_wrap_alert(`${voper} ok`);
+  else
+    vmp_wrap_alert(`${voper} error '${req.close_msg_}'`);
+}
