@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/12/2024
+   Date last update: 24/02/2025
  */
 /**
   *@return {String} author project
@@ -338,6 +338,22 @@ function vmp_unicode_str_format_maxline(content,maxline)
   }
   return ret;
 }
+function vmp_unicode_str_format_lines(content,linesize)
+{
+  let line=0;
+  let ret="";       
+  for(let i=0;i<content.length;i++)
+  {
+    if(line > linesize)
+    {
+      ret += "\n";
+      line=0;
+    }
+    ret += content[i];
+    line++;
+  }
+  return ret;
+}
 /**
   *Remove all characters with ascii code <= 0x20 or >= 0x7E at the end of the string
   *@param content {String} input string
@@ -534,7 +550,7 @@ function vmp_unicode_shlex_join(vargs)
 */
 function vmp_unicode_str_toindex_list(istr,minvalue,maxvalue)
 {
-  let ret,value,split,split2,min,max;
+  let ret=[],value,split,split2,min,max;
   if(minvalue > maxvalue)
     vmp_except(`minvalue ${minvalue} not less maxvalue ${maxvalue} in input`);
   split=vmp_unicode_str_split(istr,",");
