@@ -16,21 +16,22 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date : 18/03/2020
+#Date : 05/04/2024
 
 import vmp
 import vmp_plugin as plugin
 
 def module(par,var):
   m=plugin.module_import(par[0])
-  vmp.output(m.print_topic())
-  for v in var:
+  if len(par) == 1:
+    vmp.output(m.print_topic())
+  else:
     try:
-      topic=plugin.plugin_import_topic(par[0],v)
-      vmp.output("\n{0}".format(topic.print_topic()))
+      topic=plugin.plugin_import_topic(par[0],par[1])
+      vmp.output("{0}".format(topic.print_topic()))
     except Exception as e:
-      vmp.error(str(e))  
-  
+      vmp.error(str(e))
+
 def vmp_main():
   vmp.input_f("module",module)
   vmp.exit_ok() 
